@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -285,9 +285,17 @@ function form_actions() {
                     raise_message('reports_graphs_added');
                 }
 			} elseif (get_request_var('drp_action') == '10') { // associate with aggregate
-				api_aggregate_associate($selected_items);
+				$local_graph_id = get_filter_request_var('local_graph_id');
+				api_aggregate_associate($local_graph_id, $selected_items);
+
+				header('Location: aggregate_graphs.php?header=false&action=edit&tab=items&id=' . $local_graph_id);
+				exit;
 			} elseif (get_request_var('drp_action') == '11') { // dis-associate with aggregate
-				api_aggregate_disassociate($selected_items);
+				$local_graph_id = get_filter_request_var('local_graph_id');
+				api_aggregate_disassociate($local_graph_id, $selected_items);
+
+				header('Location: aggregate_graphs.php?header=false&action=edit&tab=items&id=' . $local_graph_id);
+				exit;
 			} elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { // place on tree
 				get_filter_request_var('tree_id');
 				get_filter_request_var('tree_item_id');
@@ -353,11 +361,15 @@ function form_actions() {
 				FROM graph_templates_item
 				WHERE local_graph_id IN($lgid)"), 'task_item_id', 'task_item_id');
 
-			$task_items = implode(',', $task_items);
+			if (cacti_sizeof($task_items)) {
+				$task_items = implode(',', $task_items);
 
-			$graph_templates = db_fetch_assoc("SELECT DISTINCT graph_template_id
-				FROM graph_templates_item
-				WHERE task_item_id IN ($task_items) AND graph_template_id>0");
+				$graph_templates = db_fetch_assoc("SELECT DISTINCT graph_template_id
+					FROM graph_templates_item
+					WHERE task_item_id IN ($task_items) AND graph_template_id>0");
+			} else {
+				$graph_templates = array();
+			}
 
 			if (cacti_sizeof($graph_templates) > 1) {
 				print "<tr>
@@ -369,8 +381,16 @@ function form_actions() {
 				</tr>\n";
 
 				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+			} elseif (cacti_sizeof($graph_templates) == 0) {
+				print "<tr>
+					<td class='textArea'>
+						<p>" . __('The selected Aggregate Graphs does not appear to have any matching Aggregate Templates.') . "</p>
+						<p>" . __('In order to migrate the Aggregate Graphs below use an Aggregate Template, one must already exist.  Please press \'Return\' and then first create your Aggergate Template before retrying.') . "</p>
+						<div class='itemlist'><ul>$graph_list</ul></div>
+					</td>
+				</tr>\n";
 			} else {
-				$graph_template      = $graph_templates[0]['graph_template_id'];
+				$graph_template = $graph_templates[0]['graph_template_id'];
 
 				$aggregate_templates = db_fetch_assoc_prepared('SELECT id, name
 					FROM aggregate_graph_templates
@@ -694,7 +714,7 @@ function graph_edit() {
 	if (!isempty_request_var('id') && $current_tab == 'preview') {
 		html_start_box(__('Aggregate Preview [%s]', $header_label), '100%', '', '3', 'center', '');
 		?>
-		<tr><td class='center'>
+		<tr><td id='imagewindow' class='center'>
 			<img src='<?php print html_escape($config['url_path'] . 'graph_image.php?action=edit&disable_cache=1&local_graph_id=' . get_request_var('id') . '&rra_id=' . read_user_setting('default_rra_id') . '&random=' . mt_rand());?>' alt=''>
 		</td></tr>
 		<?php
@@ -702,14 +722,18 @@ function graph_edit() {
 			$graph_data_array['output_flag'] = RRDTOOL_OUTPUT_STDERR;
 			$graph_data_array['print_source'] = 1;
 			?>
-			<tr><td class='left'>
+			<tr><td id='rrdtoolinfo' class='left' style='padding-left:15px;max-width:900px;overflow:scroll'>
 				<div style='overflow:auto;'>
-				<span class='textInfo'><?php print __('RRDtool Command:');?></span><br>
-				<pre class='monoSpace tableRow'><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
-				<span class='textInfo'><?php print __('RRDtool Says:');?></span><br>
-				<?php unset($graph_data_array['print_source']);?>
-				<pre class='monoSpace tableRow'><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
+					<span class='textInfo'><?php print __('RRDtool Command:');?></span><br>
+					<?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?>
+					<span class='textInfo'><?php print __('RRDtool Says:');?></span><br><?php unset($graph_data_array['print_source']);?><pre class='monoSpace tableRow left'><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
 				</div>
+				<script type='text/javascript'>
+				$(function() {
+					var width = $(window).width() - $('.cactiConsoleNavigationArea').width();
+					$('#rrdtoolinfo, #imagewindow').css('max-width', width);
+				});
+				</script>
 			</td></tr>
 			<?php
 		}
@@ -820,6 +844,8 @@ function graph_edit() {
 					}
 
 					changeTotals();
+
+					updateSaveButton();
 				});
 
 				$('#total').change(function() {
@@ -841,8 +867,26 @@ function graph_edit() {
 						}
 					}
 				});
+
+				updateSaveButton();
 			});
 
+			function updateSaveButton() {
+				if ($('input[id^="agg_total"]').is(':checked')) {
+					$('#submit').prop('disabled', false);
+
+					if ($('#submit').button('instance')) {
+						$('#submit').button('enable');
+					}
+				} else {
+					$('#submit').prop('disabled', true);
+
+					if ($('#submit').button('instance')) {
+						$('#submit').button('disable');
+					}
+				}
+			}
+
 			function changeTotals() {
 				switch ($('#total').val()) {
 					case '<?php print AGGREGATE_TOTAL_NONE;?>':
@@ -907,7 +951,7 @@ function graph_edit() {
 						$form_array[$field_name]['value']   = (isset($graphs) ? $graphs[$field_name] : '');
 						$form_array[$field_name]['form_id'] = (isset($graphs) ? $graphs['id'] : '0');
 
-						if (!(($use_graph_template == false) || ($graphs_template['t_' . $field_name] == 'on'))) {
+						if (!(($use_graph_template == false) || ($graphs['t_' . $field_name] == 'on'))) {
 							$form_array[$field_name]['method']      = 'template_' . $form_array[$field_name]['method'];
 							$form_array[$field_name]['description'] = '';
 						}
@@ -1017,6 +1061,17 @@ function aggregate_items() {
 			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
+		'custom' => array(
+			'filter' => FILTER_VALIDATE_REGEXP,
+			'options' => array('options' => array('regexp' => '(true|false)')),
+			'pageset' => true,
+			'default' => ''
+			),
+		'local_graph_ids' => array(
+			'filter' => FILTER_VALIDATE_IS_NUMERIC_LIST,
+			'pageset' => true,
+			'default' => ''
+			)
 	);
 
 	validate_store_request_vars($filters, 'sess_agraph_item');
@@ -1149,6 +1204,10 @@ function aggregate_items() {
 		$sql_where .= ($sql_where != '' ? ' AND':'WHERE') . " (gtg.graph_template_id=$graph_template)";
 	}
 
+	if (get_request_var('local_graph_ids') != '') {
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' agi.local_graph_id IN(' . get_request_var('local_graph_ids') . ')';
+	}
+
 	/* print checkbox form for validation */
 	form_start('aggregate_graphs.php', 'chk');
 
@@ -1345,6 +1404,11 @@ function aggregate_graph() {
 			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
+		'local_graph_ids' => array(
+			'filter' => FILTER_VALIDATE_IS_NUMERIC_LIST,
+			'pageset' => true,
+			'default' => ''
+			)
 	);
 
 	validate_store_request_vars($filters, 'sess_agraph');
@@ -1395,7 +1459,7 @@ function aggregate_graph() {
 	</script>
 	<?php
 
-	html_start_box(__('Aggregate Graphs'), '100%', '', '3', 'center', '');
+	html_start_box(__('Aggregate Graphs') . (get_request_var('local_graph_ids') != '' ? __(' [ Custom Graphs List Applied - Clear to Reset ]'): ''), '100%', '', '3', 'center', '');
 
 	?>
 	<tr class='even'>
