@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -120,6 +120,8 @@ function sqltable_to_php($table, $create, $plugin = '') {
 
 				if (trim($r['Default']) != '') {
 					$text .= ", 'default' => '" . $r['Default'] . "'";
+				} elseif (stripos($r['Type'], 'char') !== false) {
+					$text .= ", 'default' => ''";
 				}
 
 				if (trim($r['Extra']) != '') {
@@ -153,7 +155,7 @@ function sqltable_to_php($table, $create, $plugin = '') {
 			}
 
 			if (!empty($pri)) {
-				if ($plugin != '') {
+				if ($plugin != '' || $create) {
 					$text .= "\$data['primary'] = '" . implode("`,`", $pri) . "';\n";
 				} else {
 					$text .= "\$data['primary'] = array('" . implode("','", $pri) . "');\n";
@@ -174,7 +176,12 @@ function sqltable_to_php($table, $create, $plugin = '') {
 			//exit;
 		}
 
-		$result = db_fetch_row("SELECT ENGINE, TABLE_COMMENT FROM information_schema.TABLES WHERE TABLE_NAME = '$table'");
+		$result = db_fetch_row_prepared('select ENGINE, TABLE_COMMENT
+			FROM information_schema.TABLES
+			WHERE TABLE_SCHEMA = SCHEMA()
+			AND TABLE_NAME = ?',
+			array($table));
+
 		if (cacti_sizeof($result)) {
 			$text .= "\$data['type'] = '" . $result['ENGINE'] . "';\n";
 			$text .= "\$data['comment'] = '" . $result['TABLE_COMMENT'] . "';\n";
