@@ -162,7 +162,7 @@ function debug($message) {
 global $poller_id, $sessions, $downhosts, $remote_db_cnn_id;
 
 ini_set('max_execution_time', '0');
-ini_set('memory_limit', '512M');
+ini_set('memory_limit', '-1');
 
 $no_http_headers = true;
 
@@ -241,17 +241,16 @@ if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
 	$poller_db_cnn_id = false;
 }
 
-if ($first == NULL || $last == NULL ) {
-	cacti_log('FATAL: You must either a host range, or no range at all using --first=N --last=N syntax!', true, 'POLLER');
-	exit(-1);
-} elseif (!is_numeric($first) || $first <0) {
+if ($first == NULL && $last == NULL) {
+	// This is valid
+} elseif (!is_numeric($first) || $first < 0) {
 	cacti_log('FATAL: The first host in the host range is invalid!', true, 'POLLER');
 	exit(-1);
-} elseif (!is_numeric($last) || $last <0) {
+} elseif (!is_numeric($last) || $last < 0) {
 	cacti_log('FATAL: The last host in the host range is invalid!', true, 'POLLER');
 	exit(-1);
 } elseif ($last < $first) {
-	cacti_log('FATAL: The first host must always be less or equal to the last host!=', true, 'POLLER');
+	cacti_log('FATAL: The first host must always be less or equal to the last host!', true, 'POLLER');
 	exit(-1);
 }
 
@@ -482,17 +481,26 @@ if ((cacti_sizeof($polling_items) > 0) && (read_config_option('poller_enabled')
 			$host_update_time = date('Y-m-d H:i:s'); // for poller update time
 
 			if ($last_host != '') {
+				$host_end = microtime(true);
+
+				db_execute_prepared('UPDATE host
+					SET polling_time = ?
+					WHERE id = ?',
+					array(($host_end - $host_start), $last_host));
+
 				if (cacti_sizeof($error_ds)) {
 					cacti_log('WARNING: Invalid Response(s), Errors[' . cacti_sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
 				}
 
 				$error_ds = array();
 			}
+
+			$host_start = microtime(true);
 		}
 
 		$host_id = $item['host_id'];
 
-		if (($new_host) && (!empty($host_id))) {
+		if ($new_host && !empty($host_id) && isset($hosts[$host_id])) {
 			$ping->host = $item;
 			$ping->port = $hosts[$host_id]['ping_port'];
 
@@ -535,10 +543,8 @@ if ((cacti_sizeof($polling_items) > 0) && (read_config_option('poller_enabled')
 						case POLLER_ACTION_SNMP: // snmp
 							open_snmp_session($host_id, $item);
 
-
 							if (isset($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']])) {
-								$sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']]->quick_print = true;
-								$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1'], true);
+								$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1']);
 							} else {
 								$output = 'U';
 							}
@@ -798,6 +804,14 @@ if ((cacti_sizeof($polling_items) > 0) && (read_config_option('poller_enabled')
 		}
 	}
 
+	// Record the last hosts polling time
+	$host_end = microtime(true);
+
+	db_execute_prepared('UPDATE host
+		SET polling_time = ?
+		WHERE id = ?',
+		array(($host_end - $host_start), $last_host));
+
 	if (cacti_sizeof($error_ds)) {
 		cacti_log('WARNING: Invalid Response(s), Errors[' . cacti_sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
 	}
