@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -140,7 +140,9 @@ function form_save() {
 			if ($snmp_query_id) {
 				raise_message(1);
 
-				data_query_update_input_method($snmp_query_id, $previous_input_id, $save['data_input_id']);
+				if (isset($previous_input_id) && $previous_input_id > 0) {
+					data_query_update_input_method($snmp_query_id, $previous_input_id, $save['data_input_id']);
+				}
 
 				update_replication_crc(0, 'poller_replicate_snmp_query_crc');
 			} else {
@@ -163,7 +165,7 @@ function form_save() {
 		$save['graph_template_id'] = get_request_var('graph_template_id');
 
 		$header = '';
-
+		$errors = false;
 		if (!is_error_message()) {
 			if ($save['id'] > 0) {
 				$errors = api_data_query_errors($save['id'], $_POST);
@@ -665,9 +667,19 @@ function data_query_item_edit() {
 
 	?>
 	<script type='text/javascript'>
-	$('#graph_template_id').change(function() {
-		$('#name').val($(this).children(':selected').text());
+	function assignDataQueryGraphName(init) {
+		if (init == false || $('#name').val() == '') {
+			$('#name').val($('#graph_template_id').children(':selected').text());
+		}
+	}
+
+	$(function() {
+		$('form#data_queries').find('#graph_template_id').change(function() {
+			assignDataQueryGraphName(false);
+		});
+		assignDataQueryGraphName(true);
 	});
+
 	</script>
 	<?php
 
@@ -739,7 +751,7 @@ function data_query_item_edit() {
 										form_dropdown('dsdt_' . $data_template['id'] . '_' . $data_template_rrd['id'] . '_snmp_field_output',$xml_outputs,'','',$data_template_rrd['snmp_field_name'],'','');?>
 									</td>
 									<td class='right'>
-										<?php form_checkbox('dsdt_' . $data_template['id'] . '_' . $data_template_rrd['id'] . '_check', $old_value, '', '', '', get_request_var('id'), '', _('If this Graph Template requires the Data Template Data Source to the left, select the correct XML output column and then to enable the mapping either check or toggle here.')); print '<br>';?>
+										<?php form_checkbox('dsdt_' . $data_template['id'] . '_' . $data_template_rrd['id'] . '_check', $old_value, '', '', '', get_request_var('id'), '', __('If this Graph Template requires the Data Template Data Source to the left, select the correct XML output column and then to enable the mapping either check or toggle here.')); print '<br>';?>
 									</td>
 								</tr>
 							</table>
