@@ -268,13 +268,31 @@ function form_save() {
 							array($rrd['id']));
 
 						$save3['data_template_id'] = get_filter_request_var('data_template_id');
+
 						$save3['rrd_maximum'] = form_input_validate(get_nfilter_request_var("rrd_maximum$name_modifier"), "rrd_maximum$name_modifier", "^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$|\|query_ifSpeed\||\|query_ifHighSpeed\|", false, 3);
+
 						$save3['rrd_minimum'] = form_input_validate(get_nfilter_request_var("rrd_minimum$name_modifier"), "rrd_minimum$name_modifier", "^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$|\|query_ifSpeed\||\|query_ifHighSpeed\|", false, 3);
+
 						$save3['rrd_heartbeat'] = form_input_validate(get_nfilter_request_var("rrd_heartbeat$name_modifier"), "rrd_heartbeat$name_modifier", '^[0-9]+$', false, 3);
+
 						$save3['data_source_type_id'] = form_input_validate(get_nfilter_request_var("data_source_type_id$name_modifier"), "data_source_type_id$name_modifier", '^[0-9]+$', false, 3);
+
 						$save3['data_source_name'] = form_input_validate(get_nfilter_request_var("data_source_name$name_modifier"), "data_source_name$name_modifier", '^[a-zA-Z0-9_-]{1,19}$', false, 3);
+
 						$save3['data_input_field_id'] = form_input_validate((isset_request_var("data_input_field_id$name_modifier") ? get_nfilter_request_var("data_input_field_id$name_modifier") : '0'), "data_input_field_id$name_modifier", '', true, 3);
 
+						if ($save3['rrd_minimum'] != 'U' && $save3['rrd_maximum'] != 'U') {
+							if ($save3['rrd_minimum'] >= $save3['rrd_maximum']) {
+								raise_message(43);
+
+								$_SESSION['sess_error_fields']['rrd_maximum'] = 'rrd_maximum';
+
+								header('Location: data_sources.php?header=false&action=ds_edit&id=' . (empty($local_data_id) ? get_filter_request_var('local_data_id') : $local_data_id) . '&host_id=' . get_request_var('host_id') . '&view_rrd=' . (isset_request_var('current_rrd') ? get_nfilter_request_var('current_rrd') : '0'));
+
+								exit;
+							}
+						}
+
 						$data_template_rrd_id = sql_save($save3, 'data_template_rrd');
 
 						if ($data_template_rrd_id) {
@@ -1130,7 +1148,9 @@ function ds_edit() {
 					rrdtool_info2html($rrd_info, $diff);
 					if (cacti_sizeof($diff)) {
 						html_start_box(__('RRDtool Tune Info'), '100%', '', '3', 'center', '');
+						print '<tr><td style="padding:4px;">';
 						rrdtool_tune($rrd_info['filename'], $diff, true);
+						print '</td></tr>';
 						html_end_box();
 					}
 				}
@@ -1303,7 +1323,16 @@ function ds() {
 		$host_where = '';
 	}
 
-	html_start_box( __('Data Sources [%s]', (empty($host['hostname']) ? __('No Device') : html_escape($host['hostname']))), '100%', '', '3', 'center', $add_url);
+	if (get_request_var('host_id') == -1) {
+		$header = __('Data Sources [ All Devices ]');
+	} elseif (get_request_var('host_id') == 0) {
+		$header = __('Data Sources [ Non Device Based ]');
+	} else {
+		$description = db_fetch_cell_prepared('SELECT description FROM host WHERE id = ?', array(get_request_var('host_id')));
+		$header = __('Data Sources [ %s ]', $description);
+	}
+
+	html_start_box($header, '100%', '', '3', 'center', $add_url);
 
 	?>
 	<tr class='even noprint'>
@@ -1381,7 +1410,6 @@ function ds() {
 					<td>
 						<select id='orphans' name='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('orphans') == '-1' ? ' selected>':'>') . __('All');?></option>
-							<option value='0'<?php print (get_request_var('orphans') == '0' ? ' selected>':'>') . __('Has Graphs');?></option>
 							<option value='1'<?php print (get_request_var('orphans') == '1' ? ' selected>':'>') . __('Orphaned');?></option>
 						</select>
 					</td>
@@ -1468,45 +1496,90 @@ function ds() {
 		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' (dl.snmp_index = "" AND dl.snmp_query_id > 0)';
 	}
 
-	$orphan_where = ' AND graph_type_id IN (' .
-		GRAPH_ITEM_TYPE_LINE1     . ', ' .
-		GRAPH_ITEM_TYPE_LINE2     . ', '.
-		GRAPH_ITEM_TYPE_LINE3     . ', ' .
-		GRAPH_ITEM_TYPE_LINESTACK . ', ' .
-		GRAPH_ITEM_TYPE_AREA      . ', ' .
-		GRAPH_ITEM_TYPE_STACK     . ')';
+	if (get_request_var('orphans') >= '0') {
+		$orphan_where = 'WHERE graph_type_id IN (' .
+			GRAPH_ITEM_TYPE_LINE1     . ', ' .
+			GRAPH_ITEM_TYPE_LINE2     . ', '.
+			GRAPH_ITEM_TYPE_LINE3     . ', ' .
+			GRAPH_ITEM_TYPE_LINESTACK . ', ' .
+			GRAPH_ITEM_TYPE_AREA      . ', ' .
+			GRAPH_ITEM_TYPE_STACK     . ')';
 
-	if (get_request_var('orphans') == '0') {
-		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' dl.id IN (SELECT DISTINCT dl.id FROM data_local AS dl INNER JOIN data_template_rrd AS dtr ON dl.id=dtr.local_data_id LEFT JOIN graph_templates_item AS gti ON gti.task_item_id=dtr.id WHERE gti.id IS NOT NULL' . $orphan_where . ')';
-	} elseif (get_request_var('orphans') == 1) {
-		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . ' dl.id IN (SELECT DISTINCT dl.id FROM data_local AS dl INNER JOIN data_template_rrd AS dtr ON dl.id=dtr.local_data_id LEFT JOIN graph_templates_item AS gti ON gti.task_item_id=dtr.id WHERE gti.id IS NULL)';
+		$sql_where1 .= ($sql_where1 != '' ? ' AND':'WHERE') . " dtr.local_graph_id IS NULL";
+	} else {
+		$orphan_where = '';
 	}
 
-	$total_rows = db_fetch_cell("SELECT COUNT(*)
-		FROM data_local AS dl
-		INNER JOIN data_template_data AS dtd
-		ON dl.id=dtd.local_data_id
-		INNER JOIN data_template AS dt
-		ON dt.id=dl.data_template_id
-		INNER JOIN host AS h
-		ON h.id = dl.host_id
-		$sql_where1");
-
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
-	$data_sources = db_fetch_assoc("SELECT dtd.local_data_id, dtd.name_cache, dtd.active,
-		dtd.rrd_step, dt.name AS data_template_name, dl.host_id, dtd.data_source_profile_id
-		FROM data_local AS dl
-		INNER JOIN data_template_data AS dtd
-		ON dl.id=dtd.local_data_id
-		INNER JOIN data_template AS dt
-		ON dt.id=dl.data_template_id
-		INNER JOIN host AS h
-		ON h.id = dl.host_id
-		$sql_where1
-		$sql_order
-		$sql_limit");
+	if ($orphan_where != '') {
+		$total_rows = db_fetch_cell("SELECT COUNT(*)
+			FROM data_local AS dl
+			INNER JOIN data_template_data AS dtd
+			ON dl.id=dtd.local_data_id
+			LEFT JOIN (
+				SELECT DISTINCT dtr.local_data_id, gl.id AS local_graph_id
+				FROM data_template_rrd AS dtr
+				LEFT JOIN graph_templates_item AS gti
+				ON gti.task_item_id = dtr.id
+				LEFT JOIN graph_local AS gl
+				ON gti.local_graph_id = gl.id
+				$orphan_where
+			) AS dtr
+			ON dtr.local_data_id=dl.id
+			LEFT JOIN data_template AS dt
+			ON dt.id=dl.data_template_id
+			LEFT JOIN host AS h
+			ON h.id = dl.host_id
+			$sql_where1");
+
+		$data_sources = db_fetch_assoc("SELECT dtr.local_graph_id, dtd.local_data_id, dtd.name_cache, dtd.active,
+			dtd.rrd_step, dt.name AS data_template_name, dl.host_id, dtd.data_source_profile_id
+			FROM data_local AS dl
+			INNER JOIN data_template_data AS dtd
+			ON dl.id=dtd.local_data_id
+			LEFT JOIN (
+				SELECT DISTINCT dtr.local_data_id, gl.id AS local_graph_id
+				FROM data_template_rrd AS dtr
+				LEFT JOIN graph_templates_item AS gti
+				ON gti.task_item_id = dtr.id
+				LEFT JOIN graph_local AS gl
+				ON gti.local_graph_id = gl.id
+				$orphan_where
+			) AS dtr
+			ON dtr.local_data_id=dl.id
+			LEFT JOIN data_template AS dt
+			ON dt.id=dl.data_template_id
+			LEFT JOIN host AS h
+			ON h.id = dl.host_id
+			$sql_where1
+			$sql_order
+			$sql_limit");
+	} else {
+		$total_rows = db_fetch_cell("SELECT COUNT(*)
+			FROM data_local AS dl
+			INNER JOIN data_template_data AS dtd
+			ON dl.id=dtd.local_data_id
+			LEFT JOIN data_template AS dt
+			ON dt.id=dl.data_template_id
+			LEFT JOIN host AS h
+			ON h.id = dl.host_id
+			$sql_where1");
+
+		$data_sources = db_fetch_assoc("SELECT dtd.local_data_id, dtd.name_cache, dtd.active,
+			dtd.rrd_step, dt.name AS data_template_name, dl.host_id, dtd.data_source_profile_id
+			FROM data_local AS dl
+			INNER JOIN data_template_data AS dtd
+			ON dl.id=dtd.local_data_id
+			LEFT JOIN data_template AS dt
+			ON dt.id=dl.data_template_id
+			LEFT JOIN host AS h
+			ON h.id = dl.host_id
+			$sql_where1
+			$sql_order
+			$sql_limit");
+	}
 
 	$nav = html_nav_bar('data_sources.php', MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 7, __('Data Sources'), 'page', 'main');
 
@@ -1529,13 +1602,19 @@ function ds() {
 			'sort'    => 'ASC',
 			'tip'     => __('The internal database ID for this Data Source. Useful when performing automation or debugging.')
 		),
-		'nosort' => array(
+		'nosort0' => array(
+			'display' => __('Graphs'),
+			'align'   => 'center',
+			'sort'    => '',
+			'tip'     => __('The number of Graphs and Aggregate Graphs that are using the Data Source.')
+		),
+		'nosort1' => array(
 			'display' => __('Poller Interval'),
 			'align'   => 'left',
 			'sort'    => 'ASC',
 			'tip'     => __('The frequency that data is collected for this Data Source.')
 		),
-		'nosort1' => array(
+		'nosort2' => array(
 			'display' => __('Deletable'),
 			'align'   => 'left',
 			'sort'    => 'ASC',
@@ -1589,9 +1668,15 @@ function ds() {
 				$data_template_name = html_escape($data_source['data_template_name']);
 			}
 
+			$graphs_aggregates_url = get_graphs_aggregates_url($data_source['local_data_id']);
+
 			form_alternate_row('line' . $data_source['local_data_id'], true, $disabled);
 			form_selectable_cell(filter_value(title_trim($data_source['name_cache'], read_config_option('max_title_length')), get_request_var('rfilter'), 'data_sources.php?action=ds_edit&id=' . $data_source['local_data_id']), $data_source['local_data_id']);
 			form_selectable_cell($data_source['local_data_id'], $data_source['local_data_id'], '', 'right');
+
+			// Show link to Graphs and Aggregates
+			form_selectable_cell($graphs_aggregates_url, $data_source['local_data_id'], '', 'center');
+
 			form_selectable_cell(get_poller_interval($data_source['rrd_step'], $data_source['data_source_profile_id']), $data_source['local_data_id']);
 			form_selectable_cell(api_data_source_deletable($data_source['local_data_id']) ? __('Yes') : __('No'), $data_source['local_data_id']);
 			form_selectable_cell(($data_source['active'] == 'on' ? __('Yes'):__('No')), $data_source['local_data_id']);
@@ -1615,3 +1700,48 @@ function ds() {
 	form_end();
 }
 
+function get_graphs_aggregates_url($local_data_id) {
+	$graphs = db_fetch_row_prepared('SELECT GROUP_CONCAT(DISTINCT gl.id) AS graphs, COUNT(DISTINCT gl.id) AS total
+		FROM data_local AS dl
+		INNER JOIN data_template_rrd AS dtr
+		ON dl.id = dtr.local_data_id
+		INNER JOIN graph_templates_item AS gti
+		ON gti.task_item_id = dtr.id
+		INNER JOIN graph_local AS gl
+		ON gl.id = gti.local_graph_id
+		LEFT JOIN aggregate_graphs AS ag
+		ON ag.local_graph_id = gl.id
+		WHERE dl.id = ?
+		AND ag.local_graph_id IS NULL',
+		array($local_data_id));
+
+	$aggregates = db_fetch_row_prepared('SELECT GROUP_CONCAT(DISTINCT gl.id) AS graphs, COUNT(DISTINCT gl.id) AS total
+		FROM data_local AS dl
+		INNER JOIN data_template_rrd AS dtr
+		ON dl.id = dtr.local_data_id
+		INNER JOIN graph_templates_item AS gti
+		ON gti.task_item_id = dtr.id
+		INNER JOIN graph_local AS gl
+		ON gl.id = gti.local_graph_id
+		INNER JOIN aggregate_graphs AS ag
+		ON ag.local_graph_id = gl.id
+		WHERE dl.id = ?',
+		array($local_data_id));
+
+	$url = '';
+
+	if (cacti_sizeof($graphs) && $graphs['total'] > 0) {
+		$url .= '<a class="linkEditMain" title="' . __('Graphs') . '" href="graphs.php?reset=1&custom=true&local_graph_ids=' . $graphs['graphs'] . '">' . $graphs['total'] . '</a>';
+	} else {
+		$url .= '<span title="' . __('No Graphs') . '">0</span>';
+	}
+
+	if (cacti_sizeof($aggregates) && $aggregates['total'] > 0) {
+		$url .= ' / <a class="linkEditMain" title="' . __('Aggregates') . '" href="aggregate_graphs.php?reset=1&custom=true&local_graph_ids=' . $aggregates['graphs'] . '">' . $aggregates['total'] . '</a>';
+	} else {
+		$url .= ' / <span title="' . __('No Aggregates') . '">0</span>';
+	}
+
+	return $url;
+}
+
