@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -1332,9 +1332,12 @@ function get_device_records(&$total_rows, $rows) {
 	$sql_limit = 'LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
 	$sql_query = "SELECT host.*, graphs, data_sources,
-		IF(status_event_count>0, status_event_count*$poller_interval,
-			IF(UNIX_TIMESTAMP(status_rec_date)>943916400,UNIX_TIMESTAMP()-UNIX_TIMESTAMP(status_rec_date),
-			IF(snmp_sysUptimeInstance>0 AND snmp_version > 0, snmp_sysUptimeInstance,UNIX_TIMESTAMP()))) AS instate
+		CAST(IF(availability_method = 0, '0',
+			IF(status_event_count > 0 AND status IN (1, 2), status_event_count*$poller_interval,
+			IF(UNIX_TIMESTAMP(status_rec_date) < 943916400 AND status IN (0, 3), total_polls*$poller_interval,
+			IF(UNIX_TIMESTAMP(status_rec_date) > 943916400, UNIX_TIMESTAMP() - UNIX_TIMESTAMP(status_rec_date),
+			IF(snmp_sysUptimeInstance>0 AND snmp_version > 0, snmp_sysUptimeInstance/100, UNIX_TIMESTAMP()
+		))))) AS unsigned) AS instate
 		FROM host
 		LEFT JOIN (SELECT host_id, COUNT(*) AS graphs FROM graph_local GROUP BY host_id) AS gl
 		ON host.id=gl.host_id
@@ -1631,15 +1634,9 @@ function host() {
 			if ($host['disabled'] == '' &&
 				($host['status'] == HOST_RECOVERING || $host['status'] == HOST_UP) &&
 				($host['availability_method'] != AVAIL_NONE && $host['availability_method'] != AVAIL_PING)) {
-				$snmp_uptime = $host['snmp_sysUpTimeInstance'];
-				$days      = intval($snmp_uptime / (60*60*24*100));
-				$remainder = $snmp_uptime % (60*60*24*100);
-				$hours     = intval($remainder / (60*60*100));
-				$remainder = $remainder % (60*60*100);
-				$minutes   = intval($remainder / (60*100));
-				$uptime    = $days . 'd:' . $hours . 'h:' . $minutes . 'm';
+				$uptime    = get_uptime($host);
 			} else {
-				$uptime    = "N/A";
+				$uptime    = __('N/A');
 			}
 
 			$graphs_url      = $config['url_path'] . 'graphs.php?reset=1&host_id=' . $host['id'];
