@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,7 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-global $menu, $menu_glyphs;
+global $menu, $menu_glyphs, $graph_sources;
 
 /* Array of Cacti versions and template hash codes
    Remember to add every version here. */
@@ -113,6 +113,10 @@ $cacti_version_codes = array(
 	'1.1.37' => '0101',
 	'1.1.38' => '0101',
 	'1.2.0'  => '0101',
+	'1.2.1'  => '0101',
+	'1.2.2'  => '0101',
+	'1.2.3'  => '0102',
+	'1.2.4'  => '0102',
 );
 
 $messages = array(
@@ -242,6 +246,9 @@ $messages = array(
 	42 => array(
 		'message' => __('Save Successful. Settings replicated to Remote Data Collectors.'),
 		'level' => MESSAGE_LEVEL_INFO),
+	43 => array(
+		'message' => __('Save Failed.  Minimum Values must be less than Maximum Value.'),
+		'level' => MESSAGE_LEVEL_ERROR),
 	'input_save_wo_ds' => array(
 		'message' => __('Data Input Saved.  You must update the Data Templates referencing this Data Input Method before creating Graphs or Data Sources.'),
 		'level' => MESSAGE_LEVEL_INFO),
@@ -347,6 +354,12 @@ $messages = array(
 	'resource_cache_rebuild' => array(
 		'message' => __('Poller Resource Cache cleared.  Main Data Collector will rebuild at the next poller start, and Remote Data Collectors will sync afterwards.'),
 		'level' => MESSAGE_LEVEL_INFO),
+	'permission_denied' => array(
+		'message' => __('Permission Denied.  You do not have permission to the requested action.'),
+		'level' => MESSAGE_LEVEL_ERROR),
+	'page_not_defined' => array(
+		'message' => __('Page is not defined.  Therefore, it can not be displayed.'),
+		'level' => MESSAGE_LEVEL_ERROR),
 	'custom_error' => array(
 		'message' => __('Unexpected error occurred'),
 		'level' => MESSAGE_LEVEL_ERROR)
@@ -389,6 +402,10 @@ $cdef_functions = array(1 =>
 	'LTIME'
 );
 
+if (cacti_version_compare(get_rrdtool_version(), '1.8.0', '>=')) {
+	$cdef_functions[] = 'ROUND';
+}
+
 $vdef_functions = array(1 =>
 	'MAXIMUM',
 	'MINIMUM',
@@ -772,6 +789,8 @@ $rrdtool_versions = array(
 	'1.5.0' => 'RRDtool 1.5+',
 	'1.6.0' => 'RRDtool 1.6+',
 	'1.7.0' => 'RRDtool 1.7+',
+	'1.7.1' => 'RRDtool 1.7.1+',
+	'1.7.2' => 'RRDtool 1.7.2+',
 	'1.8.0' => 'RRDtool 1.8+'
 );
 
@@ -842,6 +861,9 @@ $custom_data_source_types = array(
 
 if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 	$menu = array(
+		__('Main Console') => array(
+			'index.php' => __('Console Page')
+			),
 		__('Create') => array(
 			'graphs_new.php' => __('New Graphs'),
 			'host.php?action=edit' => __('New Device')
@@ -917,6 +939,7 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 }
 
 $menu_glyphs = array(
+	__('Main Console') => 'fa fa-map',
 	__('Create') => 'fa fa-chart-area',
 	__('Management') => 'fa fa-home',
 	__('Data Collection') => 'fa fa-database',
@@ -967,21 +990,44 @@ $log_tail_lines = array(
 );
 
 $item_rows = array(
-	10   => '10',
-	15   => '15',
-	20   => '20',
-	25   => '25',
-	26   => '26',
-	27   => '27',
-	30   => '30',
-	40   => '40',
-	44   => '44',
-	45   => '45',
-	50   => '50',
-	100  => '100',
-	250  => '250'
+	10    => '10',
+	15    => '15',
+	16    => '16',
+	17    => '17',
+	18    => '18',
+	19    => '19',
+	20    => '20',
+	21    => '21',
+	22    => '22',
+	23    => '23',
+	24    => '24',
+	25    => '25',
+	26    => '26',
+	27    => '27',
+	30    => '30',
+	40    => '40',
+	44    => '44',
+	45    => '45',
+	50    => '50',
+	100   => '100',
+	250   => '250',
+	500   => '500',
+	750   => '750',
+	1000  => '1000',
+	2000  => '2000',
+	3000  => '3000',
+	4000  => '4000',
+	5000  => '5000',
 );
 
+// Adjust the number of items rows based upon max_input_vars
+$max_size = ini_get('max_input_vars') - 20;
+foreach($item_rows as $index => $row) {
+	if ($index > $max_size) {
+		unset($item_rows[$index]);
+	}
+}
+
 $graphs_per_page = array(
 	4   => '4',
 	6   => '6',
@@ -1364,15 +1410,17 @@ $boost_max_runtime = array(
 );
 
 $boost_max_memory = array(
-	'32'   => __('%d MBytes', 32),
-	'64'   => __('%d MBytes', 64),
-	'128'  => __('%d MBytes', 128),
 	'256'  => __('%d MBytes', 256),
 	'512'  => __('%d MBytes', 512),
-	'1024' => __('1 GByte'),
+	'1024' => __('%d GByte', 1),
 	'1536' => __('%s GBytes', '1.5'),
 	'2048' => __('%d GBytes', 2),
-	'3072' => __('%d GBytes', 3)
+	'3072' => __('%d GBytes', 3),
+	'4096' => __('%d GBytes', 4),
+	'5120' => __('%d GBytes', 5),
+	'6144' => __('%d GBytes', 6),
+	'8192' => __('%d GBytes', 8),
+	'-1' => __('Infinity')
 );
 
 $realtime_window = array(
@@ -1389,6 +1437,8 @@ $realtime_window = array(
 );
 
 $realtime_refresh = array(
+	1   => __('%d Seconds', 1),
+	2   => __('%d Seconds', 2),
 	5   => __('%d Seconds', 5),
 	10  => __('%d Seconds', 10),
 	15  => __('%d Seconds', 15),
@@ -1475,12 +1525,15 @@ $agg_graph_types = array(
 	GRAPH_ITEM_TYPE_LINE1             => __('Convert to LINE1 Graph'),
 	GRAPH_ITEM_TYPE_LINE2             => __('Convert to LINE2 Graph'),
 	GRAPH_ITEM_TYPE_LINE3             => __('Convert to LINE3 Graph'),
+	AGGREGATE_GRAPH_TYPE_LINE1_STACK  => __('Convert to LINE1/STACK Graph'),
+	AGGREGATE_GRAPH_TYPE_LINE2_STACK  => __('Convert to LINE2/STACK Graph'),
+	AGGREGATE_GRAPH_TYPE_LINE3_STACK  => __('Convert to LINE3/STACK Graph'),
 );
 
 $agg_totals = array(
 	AGGREGATE_TOTAL_NONE => __('No Totals'),
-	AGGREGATE_TOTAL_ALL  => __('Print all Legend Items'),
-	AGGREGATE_TOTAL_ONLY => __('Print totaling Legend Items Only'),
+	AGGREGATE_TOTAL_ALL  => __('Print All Legend Items'),
+	AGGREGATE_TOTAL_ONLY => __('Print Totaling Legend Items Only'),
 );
 
 $agg_totals_type = array(
@@ -2565,4 +2618,69 @@ $navigation = array(
 	)
 );
 
+$snmpagent_event_severity = array(
+	SNMPAGENT_EVENT_SEVERITY_LOW      => 'low',
+	SNMPAGENT_EVENT_SEVERITY_MEDIUM   => 'medium',
+	SNMPAGENT_EVENT_SEVERITY_HIGH     => 'high',
+	SNMPAGENT_EVENT_SEVERITY_CRITICAL => 'critical'
+);
+
+$days_from_time_settings = array(
+	'mods' => array(
+		'd' => 86400,
+		'h' => 3600,
+		'm' => '60',
+		's' => 0,
+	),
+	'text' => array(
+		DAYS_FORMAT_SHORT => array(
+			'd' => 'd',
+		        'h' => 'h',
+		        'm' => 'm',
+			's' => 's',
+			'suffix' => ':',
+			'prefix' => '',
+		),
+		DAYS_FORMAT_MEDIUM => array(
+			'd' => __('days'),
+			'h' => __('hrs'),
+			'm' => __('mins'),
+			's' => __('secs'),
+			'suffix' => ', ',
+			'prefix' => ' ',
+		),
+		DAYS_FORMAT_MEDIUM_LOG => array(
+			'd' => 'days',
+			'h' => 'hrs',
+			'm' => 'mins',
+			's' => 'secs',
+			'suffix' => ', ',
+			'prefix' => ' ',
+		),
+		DAYS_FORMAT_LONG => array(
+			'd' => __('days'),
+			'h' => __('hours'),
+			'm' => __('minutes'),
+			's' => __('seconds'),
+			'suffix' => ', ',
+			'prefix' => ' ',
+		),
+		DAYS_FORMAT_LONG_LOG => array(
+			'd' => 'days',
+			'h' => 'hours',
+			'm' => 'minutes',
+			's' => 'seconds',
+			'suffix' => ', ',
+			'prefix' => ' ',
+		),
+	),
+);
+
+$graph_sources = array(
+	0 => __('Not Templated'),
+	1 => __('Data Query'),
+	2 => __('Template'),
+	3 => __('Aggregate'),
+);
+
 api_plugin_hook('config_arrays');
