@@ -46,6 +46,7 @@ define('RRDTOOL_OUTPUT_STDOUT', 1);
 define('RRDTOOL_OUTPUT_STDERR', 2);
 define('RRDTOOL_OUTPUT_GRAPH_DATA', 3);
 define('RRDTOOL_OUTPUT_BOOLEAN', 4);
+define('RRDTOOL_OUTPUT_RETURN_STDERR', 5);
 
 define('RRD_FONT_RENDER_NORMAL',  'normal');
 define('RRD_FONT_RENDER_LIGHT',   'light');
@@ -441,3 +442,8 @@ define('DAYS_FORMAT_MEDIUM', 1);
 define('DAYS_FORMAT_MEDIUM_LOG', 2);
 define('DAYS_FORMAT_LONG', 3);
 define('DAYS_FORMAT_LONG_LOG', 4);
+
+define('GRAPH_SOURCE_PLAIN', 0);
+define('GRAPH_SOURCE_DATA_QUERY', 1);
+define('GRAPH_SOURCE_TEMPLATE', 2);
+define('GRAPH_SOURCE_AGGREGATE', 3);
