@@ -1,3 +1,6 @@
+// Host Autocomplete Magic
+var pageName = basename($(location).attr('pathname'));
+
 function themeReady() {
 	var hostTimer = false;
 	var clickTimeout = false;
@@ -8,19 +11,21 @@ function themeReady() {
 	$('#navigation_right').css('height', ($(window).height()-80)+'px');
 	$('.formItemDescription').hide();
 
+	keepWindowSize();
+
 	// Setup the navigation menu
 	setMenuVisibility();
 
 	// Add nice search filter to filters
-	if ($('input[id="filter"]').length > 0) {
+	if ($('input[id="filter"]').length > 0 && $('input[id="filter"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="filter"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchFilter).parent('td').css('white-space', 'nowrap');
 	}
 
-	if ($('input[id="filterd"]').length > 0) {
+	if ($('input[id="filterd"]').length > 0 && $('input[id="filterd"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="filterd"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchFilter).parent('td').css('white-space', 'nowrap');
 	}
 
-	if ($('input[id="rfilter"]').length > 0) {
+	if ($('input[id="rfilter"]').length > 0 && $('input[id="rfilter"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="rfilter"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchRFilter).parent('td').css('white-space', 'nowrap');
 	}
 
@@ -52,38 +57,27 @@ function themeReady() {
 		$('.import_text').html(fileText);
 	}
 
-	maxWidth = 280;
+	maxWidth = 300;
 
 	$('select.colordropdown').dropcolor();
 
 	$('select').not('.colordropdown').each(function() {
 		if ($(this).prop('multiple') != true) {
-			$(this).selectmenu({
-				change: function(event, ui) {
-					$(this).val(ui.item.value).change();
-				},
-				position: {
-					my: "left top",
-					at: "left bottom",
-					collision: "flip"
-				},
-			}).each(function() {
+			$(this).each(function() {
 				id = $(this).attr('id');
-				minWidth = 0;
-				$('#'+id+' > option').each(function() {
-					width=$(this).textWidth();
-					if (width > minWidth) {
-						minWidth = width;
-					}
+
+				$(this).selectmenu({
+					change: function(event, ui) {
+						$(this).val(ui.item.value).change();
+					},
+					position: {
+						my: "left top",
+						at: "left bottom",
+						collision: "flip"
+					},
+					width: 'auto'
 				});
 
-				minWidth+=80;
-
-				if (minWidth > maxWidth) {
-					minWidth = maxWidth;
-				}
-
-				$('#'+id+'-button').css('min-width', minWidth+'px').css('max-width', maxWidth+'px').css('width','');
 				$('#'+id+'-menu').css('max-height', '250px');
 			});
 		}else{
@@ -176,7 +170,7 @@ function themeReady() {
 
 		// hide the previously shown element
 		if (element.attr('id').replace('dd', '') != graphMenuElement && graphMenuElement > 0) {
-			$('#dd'+graphMenuElement).find('.iconWrapper:first').hide('slide', { direction: 'left' }, 300);
+			$('#dd'+graphMenuElement).find('.iconWrapper:first').hide(300);
 		}
 
 		clearTimeout(graphMenuTimer);
@@ -190,7 +184,7 @@ function themeReady() {
 
 	function showGraphMenu(element) {
 		element.find('.spikekillMenu').menu('disable');
-		element.find('.iconWrapper').show('slide', { direction: 'left' }, 300, function() {
+		element.find('.iconWrapper').show(300, function() {
 			graphMenuElement = element.attr('id').replace('dd', '');;
 			$(this).find('.spikekillMenu').menu('enable');
 		});
@@ -198,36 +192,12 @@ function themeReady() {
 
 	function hideGraphMenu(element) {
 		element.find('.spikekillMenu').menu('disable');
-		element.find('.iconWrapper').hide('slide', { direction: 'left' }, 300, function() {
+		element.find('.iconWrapper').hide(300, function() {
 			$(this).find('.spikekillMenu').menu('enable');
 		});
 	}
 
-
-	// Hid the scroll bar when not hovering
-	var hoverTimer;
-	$('.cactiConsoleNavigationArea').unbind().mouseenter(function() {
-		clearTimeout(hoverTimer);
-		hoverTimer = setTimeout(function() {
-			$('.cactiConsoleNavigationArea').css('overflow-y', 'auto');
-		}, 500);
-	}).mouseleave(function() {
-		clearTimeout(hoverTimer);
-		hoverTimer = setTimeout(function() {
-			$('.cactiConsoleNavigationArea').css('overflow-y', 'hidden');
-		}, 500);
-	});
-	$('.cactiTreeNavigationArea').unbind().mouseenter(function() {
-		clearTimeout(hoverTimer);
-		hoverTimer = setTimeout(function() {
-			$('.cactiTreeNavigationArea').css('overflow-y', 'auto');
-		}, 500);
-	}).mouseleave(function() {
-		clearTimeout(hoverTimer);
-		hoverTimer = setTimeout(function() {
-			$('.cactiTreeNavigationArea').css('overflow-y', 'hidden');
-		}, 500);
-	});
+	setNavigationScroll();
 }
 
 function setMenuVisibility() {
@@ -238,14 +208,12 @@ function setMenuVisibility() {
 	$('#navigation').hide();
 	$('li.menuitem').each(function() {
 		active = storage.get($(this).attr('id'));
-		if (active != null) {
-			if (active == 'active') {
-				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
-				$(this).next('a').show();
-			}else{
-				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
-				$(this).next('a').hide();
-			}
+		if (active != null && active == 'active') {
+			$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
+			$(this).next('a').show();
+		}else{
+			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
+			$(this).next('a').hide();
 		}
 
 		if ($(this).find('a.selected').length) {
