@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -30,16 +30,30 @@ function prime_default_settings() {
 			if (cacti_sizeof($tab_array)) {
 				foreach($tab_array as $setting => $attributes) {
 					if (isset($attributes['default'])) {
-						db_execute_prepared('INSERT IGNORE INTO settings
-							(name, value) VALUES (?, ?)',
-							array($setting, $attributes['default']));
+						$current = db_fetch_cell_prepared('SELECT value
+							FROM settings
+							WHERE name = ?',
+							array($setting));
+
+						if ($current == '' || $current == null) {
+							db_execute_prepared('INSERT IGNORE INTO settings
+								(name, value) VALUES (?, ?)',
+								array($setting, $attributes['default']));
+						}
 					} elseif (isset($attributes['items'])) {
 						foreach($attributes['items'] as $isetting => $iattributes) {
 							if (isset($iattributes['default'])) {
-								db_execute_prepared('INSERT IGNORE INTO settings
-									(name, value)
-									VALUES (?, ?)',
-									array($isetting, $iattributes['default']));
+								$current = db_fetch_cell_prepared('SELECT value
+									FROM settings
+									WHERE name = ?',
+									array($isetting));
+
+								if ($current == '' || $current == null) {
+									db_execute_prepared('INSERT IGNORE INTO settings
+										(name, value)
+										VALUES (?, ?)',
+										array($isetting, $iattributes['default']));
+								}
 							}
 						}
 					}
@@ -313,7 +327,8 @@ function install_setup_get_templates() {
 		'Generic_SNMP_Device.xml.gz',
 		'Local_Linux_Machine.xml.gz',
 		'NetSNMP_Device.xml.gz',
-		'Windows_Device.xml.gz'
+		'Windows_Device.xml.gz',
+		'Cacti_Stats.xml.gz'
 	);
 
 	$path = $config['base_path'] . '/install/templates';
@@ -335,7 +350,7 @@ function install_setup_get_templates() {
 			$info[] = $data['info'];
 		} else {
 			// Loading Template Information from package
-			$myinfo = @json_decode(shell_exec(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . "/cli/import_package.php --filename=/$path/$xmlfile --info-only"), true);
+			$myinfo = @json_decode(shell_exec(cacti_escapeshellcmd(read_config_option('path_php_binary')) . ' -q ' . cacti_escapeshellarg($config['base_path'] . '/cli/import_package.php') . ' --filename=' . cacti_escapeshellarg("/$path/$xmlfile") . ' --info-only'), true);
 			$myinfo['filename'] = $xmlfile;
 			$info[] = $myinfo;
 			$info[] = array('filename' => $xmlfile, 'name' => $xmlfile);
@@ -423,7 +438,7 @@ function install_tool_path($name, $defaultPaths) {
 	}
 
 	$which_tool = '';
-	if (config_value_exists('path_'.$name)) {
+	if (config_value_exists('path_' . $name)) {
 		$which_tool = read_config_option('path_'.$name, true);
 		log_install_high('file', "Using config location: $which_tool");
 	}
@@ -508,20 +523,33 @@ function install_file_paths() {
 	/* spine Binary Path */
 	$input['path_spine'] = install_tool_path('spine',
 		array(
-			'unix'  => '/usr/local/spine/bin/spine',
+			'unix'  => '/usr/bin/spine',
 			'win32' => 'c:/spine/bin/spine.exe'
 		));
 
 	$input['path_spine_config'] = $settings['path']['path_spine_config'];
 
 	/* log file path */
-	$input['path_cactilog'] = $settings['path']['path_cactilog'];
-	if (empty($input['path_cactilog']['default'])) {
-		$input['path_cactilog']['default'] = $config['base_path'] . '/log/cacti.log';
+	if (!config_value_exists('path_cactilog')) {
+		$input['path_cactilog'] = $settings['path']['path_cactilog'];
+		if (empty($input['path_cactilog']['default'])) {
+			$input['path_cactilog']['default'] = $config['base_path'] . '/log/cacti.log';
+		}
+	} else {
+		$input['path_cactilog'] = $settings['path']['path_cactilog'];
+		$input['path_cactilog']['default'] = read_config_option('path_cactilog');
 	}
 
 	/* stderr log file path */
-	$input['path_stderrrlog'] = $settings['path']['path_stderrlog'];
+	if (!config_value_exists('path_cactilog')) {
+		$input['path_stderrlog'] = $settings['path']['path_stderrlog'];
+		if (empty($input['path_stderrlog']['default'])) {
+			$input['path_stderrlog']['default'] = $config['base_path'] . '/log/cacti.stderr.log';
+		}
+	} else {
+		$input['path_stderrlog'] = $settings['path']['path_stderrlog'];
+		$input['path_stderrlog']['default'] = read_config_option('path_stderrlog');
+	}
 
 	/* RRDtool Version */
 	if ((@file_exists($input['path_rrdtool']['default'])) && (($config['cacti_server_os'] == 'win32') || (is_executable($input['path_rrdtool']['default']))) ) {
