@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -159,6 +159,7 @@ function aggregate_graph_templates_graph_save($local_graph_id, $graph_template_i
 		$graph_data['title_cache'] = $graph_title;
 	}
 
+	$graph_data['auto_padding']                  = 'on';
 	$graph_data['local_graph_id']                = $local_graph_id;
 	$graph_data['local_graph_template_graph_id'] = 0; # no templating
 	$graph_data['graph_template_id']             = 0; # no templating
@@ -248,6 +249,7 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 
 		# next entry will have to have a prepended text format
 		$prepend    = true;
+		$prepend_ct = 0;
 		$skip_graph = false;
 		$make0_cdef = aggregate_cdef_make0();
 		$i = 0;
@@ -255,11 +257,31 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 		foreach ($graph_items as $graph_item) {
 			# loop starts at 0, but $_skip starts at 1, so increment before comparing
 			$i++;
+
 			# go ahead, if this graph item has to be skipped
 			if (isset($_skip[$i]) && !empty($_skip[$i])) {
 				continue;
 			}
 
+			// HRULES will only appear in the total one way or nother
+			if ($graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_HRULE) {
+				continue;
+			}
+
+			if ($graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_COMMENT) {
+				if (preg_match('/(:bits:|:bytes:|\|sum:)/', $graph_item['text_format'])) {
+					// Only skip nth percentile COMMENT values
+					$parts = explode('|', $graph_item['text_format']);
+
+					if (isset($parts[1])) {
+						$pparts = explode(':', $parts[1]);
+						if (is_numeric($pparts[0])) {
+							continue;
+						}
+					}
+				}
+			}
+
 			if ($_total == AGGREGATE_TOTAL_ONLY) {
 				# if we only need the totalling legend, ...
 				if (($graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_GPRINT) ||
@@ -289,15 +311,22 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 					$graph_item['cdef_id'] = $make0_cdef;
 
 					# try to pick the best totaling cf id
-					$graph_item['consolidation_function_id'] = db_fetch_cell('SELECT DISTINCT consolidation_function_id
+					$graph_item['consolidation_function_id'] = db_fetch_cell('SELECT consolidation_function_id
 						FROM graph_templates_item
-						WHERE color_id>0
+						WHERE color_id > 0
 						AND sequence = ' . $graph_item['sequence'] .
 						(cacti_sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
 						(cacti_sizeof($_skip) ? ' AND sequence NOT IN (' . implode(',', $_skip) . ')':'') .
 						(cacti_sizeof($_totali) ? ' AND sequence IN (' . implode(',', $_totali) . ')':'') . '
+						ORDER BY sequence ASC
 						LIMIT 1');
 				}
+			} elseif ($graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_AREA || 
+				$graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_LINE1 ||
+				$graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_LINE2 ||
+				$graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_LINE3 ||
+				$graph_item['graph_type_id'] == GRAPH_ITEM_TYPE_STACK) {
+				$graph_item['text_format'] = $_gprint_prefix;
 			}
 
 			# use all data from 'old' graph ...
@@ -349,17 +378,39 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 			$save['graph_type_id'] = aggregate_change_graph_type($_selected_graph_index, $save['graph_type_id'], $_graph_type);
 
 			# new item text format required?
-			if ($prepend && $_total_type != '') {
-				# pointless to add any data source item name here, cause ALL are totaled
-				$save['text_format'] = $_gprint_prefix;
+			if ($_total_type != '') {
+				if ($prepend) {
+					if ($_total_type == AGGREGATE_TOTAL_TYPE_ALL && $prepend_cnt > 0) {
+						continue;
+					}
 
-				# no more prepending until next line break is encountered
-				$prepend = false;
-			} elseif (!$prepend && $_total_type != '' && strpos($save['text_format'], ':current:')) {
-				// Accomodate gprint summation types
-				$save['text_format'] = str_replace(':current:', ':total:', $save['text_format']);
-			} elseif ($prepend && $save['text_format'] != '' && $_gprint_prefix != '') {
-				$save['text_format'] = substitute_host_data($_gprint_prefix . ' ' . $save['text_format'], '|', '|', (isset($graph_local['host_id']) ? $graph_local['host_id']:0));
+					# pointless to add any data source item name here, cause ALL are totaled
+					$save['text_format'] = $_gprint_prefix;
+
+					# no more prepending until next line break is encountered
+					$prepend = false;
+					$prepend_cnt++;
+				} elseif (strpos($save['text_format'], ':current:')) {
+					if ($_total_type == AGGREGATE_TOTAL_TYPE_ALL) {
+						// All so use sum functions
+						$save['text_format'] = str_replace(':current:', ':aggregate_sum:', $save['text_format']);
+					} else {
+						// Similar to separate
+						$save['text_format'] = str_replace(':current:', ':current:', $save['text_format']);
+					}
+				} elseif (strpos($save['text_format'], ':max:')) {
+					if ($_total_type == AGGREGATE_TOTAL_TYPE_ALL) {
+						// All so use sum functions
+						$save['text_format'] = str_replace(':max:', ':aggregate_sum:', $save['text_format']);
+					} else {
+						// Similar to separate
+						$save['text_format'] = str_replace(':max:', ':max:', $save['text_format']);
+					}
+				}
+			}
+
+			if ($save['text_format'] != '') {
+				$save['text_format'] = substitute_host_data($save['text_format'], '|', '|', (isset($graph_local['host_id']) ? $graph_local['host_id']:0));
 				cacti_log(__FUNCTION__ . ' substituted:' . $save['text_format'], true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
 				/* if this is a data query graph type, try to substitute */
@@ -368,9 +419,6 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 
 					cacti_log(__FUNCTION__ . ' substituted:' . $save['text_format'] . ' for ' . $graph_local['host_id'] . ',' . $graph_local['snmp_query_id'] . ',' . $graph_local['snmp_index'], true, 'AGGREGATE', POLLER_VERBOSITY_DEVDBG);
 				}
-
-				# no more prepending until next line break is encountered
-				$prepend = false;
 			}
 
 			# <HR> wanted?
@@ -1049,10 +1097,12 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 				$_reorder);
 		}
 
-		/* special code to add totalling graph items */
+		$_orig_graph_type = $_graph_type;
+
+		// special code to add totalling graph items
 		switch ($_total) {
 			case AGGREGATE_TOTAL_NONE: # no totalling
-				# do NOT add any totalling items
+				// do NOT add any totalling items
 
 				break;
 			case AGGREGATE_TOTAL_ALL: # any totalling option was selected ...
@@ -1060,18 +1110,19 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 
 				$cf_id = db_fetch_cell('SELECT consolidation_function_id
 					FROM graph_templates_item
-					WHERE color_id>0' .
+					WHERE color_id > 0' .
 					(cacti_sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
 					(cacti_sizeof($skipped_items) ? ' AND local_graph_id NOT IN(' . implode(',', $skipped_items) . ')':'') . '
+					ORDER BY sequence ASC
 					LIMIT 1');
 
-				/* add an empty line before total items */
+				// add an empty line before total items
 				db_execute_prepared("INSERT INTO graph_templates_item
 					(local_graph_id, graph_type_id, consolidation_function_id, text_format, value, hard_return, gprint_id, sequence)
-					VALUES (?, ?, 1, '', '', 'on', 2, ?)", array($local_graph_id, $cf_id, $next_item_sequence++));
+					VALUES (?, 1, ?, '', '', 'on', 2, ?)", array($local_graph_id, $cf_id, $next_item_sequence++));
 
 			case AGGREGATE_TOTAL_ONLY:
-				# use the prefix for totalling GPRINTs as given by the user
+				// use the prefix for totalling GPRINTs as given by the user
 				switch ($_total_type) {
 					case AGGREGATE_TOTAL_TYPE_SIMILAR:
 					case AGGREGATE_TOTAL_TYPE_ALL:
@@ -1079,19 +1130,21 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 						break;
 				}
 
-				# now skip all items, that are
-				# - explicitely marked as skipped (based on $skipped_items)
-				# - OR NOT marked as 'totalling' items
+				// now skip all items, that are
+				// - explicitely marked as skipped (based on $skipped_items)
+				// - OR NOT marked as 'totalling' items
 				for ($k=1; $k<=$item_no; $k++) {
 					cacti_log(__FUNCTION__ . ' old skip: ' . (isset($skipped_items[$k]) ? $skipped_items[$k]:''), true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
-					# skip all items, that shall not be totalled
-					if (!isset($total_items[$k])) $skipped_items[$k] = $k;
+					// skip all items, that shall not be totalled
+					if (!isset($total_items[$k])) {
+						$skipped_items[$k] = $k;
+					}
 
 					cacti_log(__FUNCTION__ . ' new skip: ' . (isset($skipped_items[$k]) ? $skipped_items[$k]:''), true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 				}
 
-				# add the 'templating' graph to the new graph, honoring skipped, hr and color
+				// add the 'templating' graph to the new graph, honoring skipped, hr and color
 				aggregate_graphs_insert_graph_items(
 					$local_graph_id,
 					$example_graph_id,
@@ -1109,8 +1162,8 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 					$_total_type,
 					$member_graphs);
 
-				# now pay attention to CDEFs
-				# next_item_sequence still points to the first totalling graph item
+				// now pay attention to CDEFs
+				// next_item_sequence still points to the first totalling graph item
 				aggregate_cdef_totalling(
 					$local_graph_id,
 					$next_item_sequence,
@@ -1136,12 +1189,254 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 				$local_graph_id,
 				$_reorder);
 		}
+
+		// Handle stacked lines properly
+		aggregate_handle_stacked_lines($local_graph_id, $_orig_graph_type, $_total, $_total_type, $_total_prefix);
+
+		// Handle aggregate nth percentiles
+		if ($_total != AGGREGATE_TOTAL_NONE) {
+			aggregate_handle_ptile_type($member_graphs, $skipped_items, $local_graph_id, $_total, $_total_type);
+		}
 	}
 
 	/* restore original error handler */
 	restore_error_handler();
 }
 
+function aggregate_handle_ptile_type($member_graphs, $skipped_items, $local_graph_id, $_total, $_total_type) {
+	$comments_hrules = db_fetch_assoc('SELECT *
+		FROM graph_templates_item
+		WHERE graph_type_id IN(' . GRAPH_ITEM_TYPE_COMMENT . ',' . GRAPH_ITEM_TYPE_HRULE . ')' .
+		(cacti_sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
+		(cacti_sizeof($skipped_items) ? ' AND local_graph_id NOT IN(' . implode(',', $skipped_items) . ')':'') . '
+		ORDER BY graph_type_id DESC');
+
+	$next_item_sequence = db_fetch_cell_prepared('SELECT MAX(sequence)
+		FROM graph_templates_item
+		WHERE local_graph_id = ?',
+		array($local_graph_id));
+
+	if (cacti_sizeof($comments_hrules)) {
+		$hrule_found = false;
+		$comment_found = false;
+
+		foreach ($comments_hrules as $item) {
+			switch($item['graph_type_id']) {
+				case GRAPH_ITEM_TYPE_COMMENT:
+					if (!$comment_found) {
+						if (preg_match('/(:bits:|:bytes:)/', $item['text_format'])) {
+							$comment_found = true;
+
+							$parts = explode('|', $item['text_format']);
+
+							if (isset($parts[1])) {
+								$pparts = explode(':', $parts[1]);
+
+								if (isset($pparts[3])) {
+									if ($_total_type == AGGREGATE_TOTAL_TYPE_ALL) {
+										// All so use sum functions
+										$pparts[3] = str_replace('current', 'aggregate_sum', $pparts[3]);
+										$pparts[3] = str_replace('max',     'aggregate_sum', $pparts[3]);
+									} else {
+										// Similar to separate
+										$pparts[3] = str_replace('current', 'aggregate', $pparts[3]);
+										$pparts[3] = str_replace('max',     'aggregate_peak', $pparts[3]);
+									}
+
+									switch($pparts[3]) {
+										case 'current':
+											$new_ppart = 'current';
+											break;
+										case 'total':
+											$new_ppart = 'aggregate_sum';
+											break;
+										case 'max':
+											$new_ppart = 'max';
+											break;
+										case 'total_peak':
+											$new_ppart = 'total_peak';
+											break;
+										case 'all_max_current':
+										case 'all_max_peak':
+										case 'aggregate_max':
+											$new_ppart = 'aggregate_peak';
+											break;
+										case 'aggregate_sum':
+										case 'aggregate_current':
+										case 'aggregate':
+										case 'aggregate_peak':
+											$new_ppart = $pparts[3];
+											break;
+									}
+
+									$pparts[3] = $new_ppart;
+
+									$parts[1] = implode(':', $pparts);
+									$item['text_format'] = implode('|', $parts);
+								}
+							}
+
+							db_execute_prepared("INSERT INTO graph_templates_item
+								(local_graph_id, graph_type_id, consolidation_function_id, text_format, value, hard_return, gprint_id, sequence)
+								VALUES (?, ?, 1, ?, '', ?, 2, ?)", array(
+									$local_graph_id,
+									GRAPH_ITEM_TYPE_COMMENT,
+									$item['text_format'],
+									$item['hard_return'],
+									$next_item_sequence++
+								)
+							);
+						}
+					}
+
+					break;
+				case GRAPH_ITEM_TYPE_HRULE:
+					if (!$hrule_found) {
+						if (preg_match('/(:bits:|:bytes:)/', $item['value'])) {
+							$hrule_found = true;
+
+							$parts = explode('|', $item['value']);
+							if (isset($parts[1])) {
+								$pparts = explode(':', $parts[1]);
+
+								if (isset($pparts[3])) {
+									if ($_total_type == AGGREGATE_TOTAL_TYPE_ALL) {
+										// All so use sum functions
+										$pparts[3] = str_replace('current', 'aggregate_sum', $pparts[3]);
+										$pparts[3] = str_replace('max',     'aggregate_sum', $pparts[3]);
+									} else {
+										// Similar to separate
+										$pparts[3] = str_replace('current', 'aggregate', $pparts[3]);
+										$pparts[3] = str_replace('max',     'aggregate_peak', $pparts[3]);
+									}
+
+									switch($pparts[3]) {
+										case 'current':
+											$new_ppart = 'current';
+											break;
+										case 'total':
+											$new_ppart = 'aggregate_sum';
+											break;
+										case 'max':
+											$new_ppart = 'max';
+											break;
+										case 'total_peak':
+											$new_ppart = 'total_peak';
+											break;
+										case 'all_max_current':
+										case 'all_max_peak':
+										case 'aggregate_max':
+											$new_ppart = 'aggregate_peak';
+											break;
+										case 'aggregate_peak':
+										case 'aggregate_sum':
+										case 'aggregate_current':
+										case 'aggregate':
+											$new_ppart = $pparts[3];
+											break;
+									}
+
+									$pparts[3] = $new_ppart;
+
+									$parts[1] = implode(':', $pparts);
+									$item['value'] = implode('|', $parts);
+								}
+							}
+
+							// add an empty line before nth percentile
+							db_execute_prepared("INSERT INTO graph_templates_item
+								(local_graph_id, graph_type_id, consolidation_function_id, text_format, value, hard_return, gprint_id, sequence)
+								VALUES (?, 1, 1, '', '', 'on', 2, ?)", array($local_graph_id, $next_item_sequence++));
+
+							db_execute_prepared("INSERT INTO graph_templates_item
+								(local_graph_id, graph_type_id, color_id, consolidation_function_id, text_format, value, hard_return, gprint_id, sequence)
+								VALUES (?, ?, ?, 1, ?, ?, '', 2, ?)", array(
+									$local_graph_id,
+									GRAPH_ITEM_TYPE_HRULE,
+									$item['color_id'],
+									$item['text_format'],
+									$item['value'],
+									$next_item_sequence++
+								)
+							);
+						}
+					}
+
+					break;
+			}
+
+			if ($hrule_found && $comment_found) {
+				break;
+			}
+		}
+	}
+}
+
+function aggregate_handle_stacked_lines($local_graph_id, $_orig_graph_type, $_total, $_total_type, $_total_prefix) {
+	// Handle the stcked line cases switch line widths
+	$width = '0.01';
+	$special_type = '';
+	$special_line = false;
+
+	switch ($_orig_graph_type) {
+		case AGGREGATE_GRAPH_TYPE_LINE1_STACK:
+			$width = '1.00';
+			$special_type = GRAPH_ITEM_TYPE_LINE1;
+			$special_line = true;
+			break;
+		case AGGREGATE_GRAPH_TYPE_LINE2_STACK:
+			$width = '2.00';
+			$special_type = GRAPH_ITEM_TYPE_LINE2;
+			$special_line = true;
+			break;
+		case AGGREGATE_GRAPH_TYPE_LINE3_STACK:
+			$width = '3.00';
+			$special_type = GRAPH_ITEM_TYPE_LINE3;
+			$special_line = true;
+			break;
+	}
+
+	if ($special_line) {
+		if ($_total == AGGREGATE_TOTAL_NONE) {
+			db_execute_prepared('UPDATE graph_templates_item
+				SET line_width = ?
+				WHERE local_graph_id = ?
+				AND graph_type_id IN (?)',
+				array($width, $local_graph_id, GRAPH_ITEM_TYPE_LINESTACK));
+		}
+
+		// Handle special case total prefix
+		db_execute_prepared('UPDATE graph_templates_item
+			SET graph_type_id = ?
+			WHERE local_graph_id = ?
+			AND text_format = ?',
+			array($special_type, $local_graph_id, $_total_prefix));
+
+		if ($_total == AGGREGATE_TOTAL_ALL) {
+			db_execute_prepared('UPDATE graph_templates_item
+				SET graph_type_id = ?, line_width = "0.01"
+				WHERE local_graph_id = ?
+				AND graph_type_id = ?
+				AND text_format != ?',
+				array(
+					GRAPH_ITEM_TYPE_LINESTACK,
+					$local_graph_id,
+					$special_type,
+					$_total_prefix
+				)
+			);
+		}
+	}
+
+	/* handle any missing lines */
+	db_execute_prepared('UPDATE graph_templates_item
+		SET line_width="0.01"
+		WHERE graph_type_id = ?
+		AND line_width="0.00"
+		AND local_graph_id = ?',
+		array(GRAPH_ITEM_TYPE_LINESTACK, $local_graph_id));
+}
+
 function aggregate_get_data_sources(&$graph_array, &$data_sources, &$graph_template) {
 	/* find out which (if any) data sources are being used by this graph, so we can tell the user */
 	if (isset($graph_array)) {
