@@ -86,6 +86,9 @@ function run_data_query($host_id, $snmp_query_id) {
 	include_once($config['library_path'] . '/api_data_source.php');
 	include_once($config['library_path'] . '/utility.php');
 
+	// Load the XML structure for custom settings detection
+	$query_array = get_data_query_array($snmp_query_id);
+
 	query_debug_timer_offset('data_query', __('Running Data Query [%s].', $snmp_query_id));
 
 	$type_id = db_fetch_cell_prepared('SELECT data_input.type_id
@@ -128,10 +131,21 @@ function run_data_query($host_id, $snmp_query_id) {
 		return false;
 	}
 
+	// SNMP Queries can specify the index as a 'source' column
+	if (!isset($query_array['index_order'])) {
+		$index_is_source = true;
+	} else {
+		$index_is_source = false;
+	}
+
 	$old_sort_field = get_best_data_query_index_type($host_id, $snmp_query_id);
 
-	/* update the sort cache */
-	$new_sort_field = update_data_query_sort_cache($host_id, $snmp_query_id);
+	/* update the sort cache if there is a sort field */
+	if ($index_is_source == false) {
+		$new_sort_field = update_data_query_sort_cache($host_id, $snmp_query_id);
+	} else {
+		$new_sort_field = $old_sort_field;
+	}
 
 	if ($new_sort_field === false) {
 		cacti_log('ERROR: Re-Indexing failed due to a NULL sort field for Device[' . $host_id . '] and DQ[' . $snmp_query_id . '].  Can not continue with Re-Index.', false, 'REINDEX');
@@ -139,18 +153,20 @@ function run_data_query($host_id, $snmp_query_id) {
 	}
 
 	$remap = false;
-	if (query_check_suitable($new_sort_field, $old_sort_field, $host_id, $snmp_query_id)) {
-		if ($old_sort_field != $new_sort_field) {
-			if ($old_sort_field != '') {
-				query_debug_timer_offset('data_query', __('WARNING: Sort Field Association has Changed.  Re-mapping issues may occur!'));
+	if ($index_is_source == false) {
+		if (query_check_suitable($new_sort_field, $old_sort_field, $host_id, $snmp_query_id)) {
+			if ($old_sort_field != $new_sort_field) {
+				if ($old_sort_field != '') {
+					query_debug_timer_offset('data_query', __('WARNING: Sort Field Association has Changed.  Re-mapping issues may occur!'));
 
-				cacti_log('WARNING: Sort Field has Changed for Device[' . $host_id . '] and DQ[' . $snmp_query_id . '].  Old Sort:' . $old_sort_field . ', New Sort:' . $new_sort_field . '.  Re-mapping issues may occur!', false, 'REINDEX');
+					cacti_log('WARNING: Sort Field has Changed for Device[' . $host_id . '] and DQ[' . $snmp_query_id . '].  Old Sort:' . $old_sort_field . ', New Sort:' . $new_sort_field . '.  Re-mapping issues may occur!', false, 'REINDEX');
+				}
+
+				$remap = true;
 			}
-
-			$remap = true;
+		} else {
+			$new_sort_field = $old_sort_field;
 		}
-	} else {
-		$new_sort_field = $old_sort_field;
 	}
 
 	query_debug_timer_offset('data_query', __('Update Data Query Sort Cache complete'));
@@ -278,21 +294,26 @@ function run_data_query($host_id, $snmp_query_id) {
 					$changed_ids[] = $data_source['local_data_id'];
 				}
 			} elseif ($data_source['snmp_index'] != '' && !$forced_type) {
-				// Found a deleted index, masking off to prevent issues
-				query_debug_timer_offset('data_query', __('Index Removal Detected! PreviousIndex: %s', $data_source['query_index']));
+				if (isset($query_array['index_transient']) && $query_array['index_transient'] == 'true') {
+					// Found removed index, but this is expected, so no action taken
+					query_debug_timer_offset('data_query', __('Transient Index Removal Detected! PreviousIndex: %s.  No action taken.', $data_source['query_index']));
+				} else {
+					// Found a deleted index, masking off to prevent issues
+					query_debug_timer_offset('data_query', __('Index Removal Detected! PreviousIndex: %s', $data_source['query_index']));
 
-				// Set the index to Null, note that the Data Source still has the value
-				db_execute_prepared('UPDATE data_local
-					SET snmp_index = ""
-					WHERE id = ?',
-					array($data_source['local_data_id']));
+					// Set the index to Null, note that the Data Source still has the value
+					db_execute_prepared('UPDATE data_local
+						SET snmp_index = ""
+						WHERE id = ?',
+						array($data_source['local_data_id']));
 
-				// Remove this item from the poller cache as it will cause wranings
-				db_execute_prepared('DELETE FROM poller_item
-					WHERE local_data_id = ?',
-					array($data_source['local_data_id']));
+					// Remove this item from the poller cache as it will cause wranings
+					db_execute_prepared('DELETE FROM poller_item
+						WHERE local_data_id = ?',
+						array($data_source['local_data_id']));
 
-				$removed_ids[] = $data_source['local_data_id'];
+					$removed_ids[] = $data_source['local_data_id'];
+				}
 			}
 
 			if ($remap && trim($new_field_value) != '' && $new_sort_field != '') {
@@ -1042,7 +1063,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 						$snmp_index = preg_replace($index_regex,"\\1", $oid);
 						$oid = $field_array['oid'] . ".$snmp_index" . (isset($field_array['oid_suffix']) ? ('.' . $field_array['oid_suffix']) : '');
-						if ($field_name == 'ifOperStatus') {
+						if ($field_name == 'ifOperStatus' || $field_name == 'ifAdminStatus') {
 							switch(true) {
 								case preg_match('/^(down|2)/i',$value):
 									$value = 'Down';
@@ -1091,12 +1112,6 @@ function query_snmp_host($host_id, $snmp_query_id) {
 							$snmp_index = $value;
 						}
 
-						/* correct bogus index value */
-						/* found in some devices such as an EMC Cellera */
-						if ($snmp_index == 0) {
-							$snmp_index = 1;
-						}
-
 						$oid = $field_array['oid'] .  '.' . $parse_value;
 
 						/* rewrite octet strings */
@@ -1140,12 +1155,6 @@ function query_snmp_host($host_id, $snmp_query_id) {
 							$snmp_index = $value;
 						}
 
-						/* correct bogus index value */
-						/* found in some devices such as an EMC Cellera */
-						if ($snmp_index == 0) {
-							$snmp_index = 1;
-						}
-
 						$oid = $field_array['oid'];
 
 						debug_log_insert('data_query', __('Found item [%s=\'%s\'] index: %s [from regexp oid value parse]', $field_name, $parse_value, $snmp_index));
