@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -27,10 +27,15 @@
      average and peak calculations.
    @returns - (mixed) The RRDfile names */
 function get_rrdfile_names() {
-	return db_fetch_assoc('SELECT data_template_data.local_data_id, data_source_path FROM data_template_data LEFT JOIN poller_item ON poller_item.local_data_id = data_template_data.local_data_id WHERE poller_item.local_data_id IS NOT NULL AND data_template_data.local_data_id != 0');
+	return db_fetch_assoc('SELECT data_template_data.local_data_id, data_source_path 
+		FROM data_template_data 
+		LEFT JOIN poller_item 
+		ON poller_item.local_data_id = data_template_data.local_data_id 
+		WHERE poller_item.local_data_id IS NOT NULL 
+		AND data_template_data.local_data_id != 0');
 }
 
-/* dsstats_debug - this simple routine print's a standard message to the console
+/* dsstats_debug - this simple routine prints a standard message to the console
      when running in debug mode.
    @returns - NULL */
 function dsstats_debug($message) {
@@ -48,10 +53,16 @@ function dsstats_debug($message) {
    @returns - NULL */
 function dsstats_get_and_store_ds_avgpeak_values($interval) {
 	global $config;
+	global $user_time, $system_time, $real_time;
+	global $total_user_time, $total_system_time, $total_real_time;
 
 	$rrdfiles = get_rrdfile_names();
 	$stats    = array();
 
+	$user_time   = 0;
+	$system_time = 0;
+	$real_time   = 0;
+
 	$use_proxy = (read_config_option('storage_location') ? true:false);
 
 	/* open a pipe to rrdtool for writing and reading */
@@ -63,6 +74,10 @@ function dsstats_get_and_store_ds_avgpeak_values($interval) {
 		$rrdtool_pipe  = $process_pipes[1];
 	}
 
+	$system_time = 0;
+	$user_time   = 0;
+	$real_time   = 0;
+
 	if (cacti_sizeof($rrdfiles)) {
 		foreach ($rrdfiles as $file) {
 			if ($file['data_source_path'] != '') {
@@ -86,6 +101,10 @@ function dsstats_get_and_store_ds_avgpeak_values($interval) {
 		dsstats_rrdtool_close($process);
 	}
 
+	$total_system_time += $system_time;
+	$total_user_time   += $user_time;
+	$total_real_time   += $real_time;
+
 	dsstats_write_buffer($stats, $interval);
 }
 
@@ -149,12 +168,12 @@ function dsstats_write_buffer(&$stats_array, $interval) {
         gather data from the RRDfile for the time period in question.  It allows RRDtool to select the RRA to
         use by simply limiting the number of rows to be returned to the default.
 
-     Once it has all of the information from the RRDfile.  It then decomposes the resulting XML file to it's
+     Once it has all of the information from the RRDfile.  It then decomposes the resulting XML file to its
      components and then calculates the AVERAGE and MAX values from that data and returns an array to the calling
      function for storage into the respective database table.
    @returns - (mixed) An array of AVERAGE, and MAX values in an RRDfile by Data Source name */
 function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool_pipe) {
-	global $config;
+	global $config, $user_time, $system_time, $real_time;
 
 	$use_proxy = (read_config_option('storage_location') ? true:false);
 
@@ -168,7 +187,7 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool
 	/* don't attempt to get information if the file does not exist */
 	if ($file_exists) {
 		/* high speed or snail speed */
-		if ($use_proxy) {
+		if ($use_proxy || !is_resource($rrdtool_pipe)) {
 			$info = rrdtool_execute("info $rrdfile", false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'DSSTATS');
 		} else {
 			$info = dsstats_rrdtool_execute("info $rrdfile", $rrdtool_pipe);
@@ -211,27 +230,26 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool
 			$i        = 0;
 			$j        = 0;
 			$def      = '';
-			$xport    = '';
+			$command  = '';
 			$dsvalues = array();
 
-
 			/* escape the file name if on Windows */
 			if ($config['cacti_server_os'] != 'unix') {
 				$rrdfile = str_replace(':', "\\:", $rrdfile);
 			}
 
-			/* setup the export command by parsing throught the internal data source names */
+			/* setup the graph command by parsing throught the internal data source names */
 			if (cacti_sizeof($dsnames)) {
 				foreach ($dsnames as $dsname => $present) {
 					if ($average) {
 						$def .= 'DEF:' . $defs[$j] . $defs[$i] . "=\"" . $rrdfile . "\":" . $dsname . ':AVERAGE ';
-						$xport .= ' XPORT:' . $defs[$j] . $defs[$i];
+						$command .= ' VDEF:' . $defs[$j] . $defs[$i] . '_out=' . $defs[$j] . $defs[$i] . ',AVERAGE PRINT:' . $defs[$j] . $defs[$i] . '_out:%lf';
 						$i++;
 					}
 
 					if ($max) {
 						$def .= 'DEF:' . $defs[$j] . $defs[$i] . "=\"" . $rrdfile . "\":" . $dsname . ':MAX ';
-						$xport .= ' XPORT:' . $defs[$j] . $defs[$i];
+						$command .= ' VDEF:' . $defs[$j] . $defs[$i] . '_out=' . $defs[$j] . $defs[$i] . ',MAXIMUM PRINT:' . $defs[$j] . $defs[$i] . '_out:%lf';
 						$i++;
 					}
 
@@ -258,76 +276,74 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool
 					break;
 			}
 
-			/* now execute the xport command */
-			$xport_cmd = 'xport --start now-1' . $interval . ' --end now ' . trim($def) . ' ' . trim($xport) . ' --maxrows 10000';
+			/* now execute the graph command */
+			$stats_cmd = 'graph x --start now-1' . $interval . ' --end now ' . trim($def) . ' ' . trim($command);
 
-			if ($use_proxy) {
-				$xport_data = rrdtool_execute($xport_cmd, false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'DSSTATS');
+			//print $stats_cmd . PHP_EOL;
+
+			if ($use_proxy || !is_resource($rrdtool_pipe)) {
+				$xport_data = rrdtool_execute($stats_cmd, false, RRDTOOL_OUTPUT_STDOUT, $rrdtool_pipe, 'DSSTATS');
 			} else {
-				$xport_data = dsstats_rrdtool_execute($xport_cmd, $rrdtool_pipe);
+				$xport_data = dsstats_rrdtool_execute($stats_cmd, $rrdtool_pipe);
 			}
 
+			$position = array();
+			$position[] = array('RETURN' => 'RETURN');
+
 			/* initialize the array of return values */
 			foreach($dsnames as $dsname => $present) {
 				$dsvalues[$dsname]['AVG']    = 0;
-				$dsvalues[$dsname]['AVGCNT'] = 0;
 				$dsvalues[$dsname]['MAX']    = 0;
+
+				if ($average) {
+					$position[] = array($dsname => 'AVG');
+				}
+
+				if ($max) {
+					$position[] = array($dsname => 'MAX');
+				}
 			}
 
 			/* process the xport array and return average and peak values */
 			if ($xport_data != '') {
 				$xport_array = explode("\n", $xport_data);
+				//print_r($xport_array);
 
 				if (cacti_sizeof($xport_array)) {
-					foreach($xport_array as $line) {
-						/* we've found an output value, let's cut it to pieces */
-						if (substr_count($line, '<v>')) {
-							$line = str_replace('<row><t>', '', $line);
-							$line = str_replace('</t>',     '', $line);
-							$line = str_replace('</v>',     '', $line);
-							$line = str_replace('</row>',   '', $line);
+					foreach($xport_array as $index => $line) {
+						if ($line == '') continue;
 
-							$values = explode('<v>', $line);
-							array_shift($values);
+						if ($index > 0) {
+							// Catch the last line
+							if (substr($line, 0, 2) == 'OK') {
+								$line  = trim($line, ' OK');
+								$parts = explode(' ', $line);
+								//print $line . PHP_EOL;
 
-							$i = 0;
-							/* sum and/or store values for later processing */
-							foreach($dsnames as $dsname => $present) {
-								if ($average) {
-									/* ignore 'NaN' values */
-									if (strtolower($values[$i]) != 'nan') {
-										$dsvalues[$dsname]['AVG'] += $values[$i];
-										$dsvalues[$dsname]['AVGCNT'] += 1;
-
-										if (!$max) {
-											if ($values[$i] > $dsvalues[$dsname]['MAX']) {
-												$dsvalues[$dsname]['MAX'] = $values[$i];
-											}
-										}
-										$i++;
+								foreach($parts as $line) {
+									$sparts = explode(':', $line);
+									switch($sparts[0]) {
+										case 'u':
+											$user_time = $sparts[1];
+											break;
+										case 's':
+											$system_time = $sparts[1];
+											break;
+										case 'r':
+											$real_time = $sparts[1];
+											break;
 									}
 								}
 
-								if ($max) {
-									/* ignore 'NaN' values */
-									if (strtolower($values[$i]) != 'nan') {
-										if ($values[$i] > $dsvalues[$dsname]['MAX']) {
-											$dsvalues[$dsname]['MAX'] = $values[$i];
-										}
-										$i++;
-									}
+								break;
+							} else {
+								foreach($position[$index] as $dsname => $stat) {
+									$dsvalues[$dsname][$stat] = trim($line);
 								}
 							}
 						}
 					}
 
-					/* calculate the average */
-					foreach($dsnames as $dsname => $present) {
-						if ($dsvalues[$dsname]['AVGCNT'] > 0) {
-							$dsvalues[$dsname]['AVG'] = $dsvalues[$dsname]['AVG'] / $dsvalues[$dsname]['AVGCNT'];
-						}
-					}
-
 					return $dsvalues;
 				}
 			}
@@ -345,12 +361,16 @@ function dsstats_obtain_data_source_avgpeak_values($rrdfile, $interval, $rrdtool
    @arg $type - (string) the type of statistics to log, either 'HOURLY', 'DAILY' or 'MAJOR'.
    @returns - null */
 function log_dsstats_statistics($type) {
-	global $start;
+	global $start, $total_user_time, $total_system_time, $total_real_time;;
 
 	/* take time and log performance data */
 	$end = microtime(true);
 
-	$cacti_stats = sprintf('Time:%01.4f ', round($end-$start,4));
+	$cacti_stats = sprintf('Time:%01.4f RRDUser:%01.4f RRDSystem:%01.4f RRDReal:%01.4f', round($end-$start,4), $total_user_time, $total_system_time, $total_real_time);
+
+	$total_user_time   = 0;
+	$total_system_time = 0;
+	$total_real_time   = 0;
 
 	/* take time and log performance data */
 	$start = microtime(true);
@@ -463,7 +483,7 @@ function dsstats_poller_output(&$rrd_update_array) {
 			$overhead         = strlen($sql_cache_prefix) + strlen($sql_suffix);
 			$overhead_last    = strlen($sql_last_prefix) + strlen($sql_last_suffix);
 
-			/* determine the keyvalue pair's to decide on how to store data */
+			/* determine the keyvalue pairs to decide on how to store data */
 			$ds_types = array_rekey(
 				db_fetch_assoc('SELECT DISTINCT data_source_name, data_source_type_id, rrd_step
 					FROM data_template_rrd
