@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,6 +23,8 @@
 */
 
 function process_tree_settings() {
+	global $current_user;
+
 	if (isset_request_var('hide')) {
 		if ((get_request_var('hide') == '0') || (get_request_var('hide') == '1')) {
 			/* only update expand/contract info is this user has rights to keep their own settings */
@@ -95,34 +97,32 @@ function grow_dhtml_trees() {
 	$default_tree_id = read_user_setting('default_tree_id');
 
 	if (empty($default_tree_id)) {
-		if (read_config_option('auth_method') != 0) {
-			$user = db_fetch_row_prepared('SELECT policy_trees
-				FROM user_auth
-				WHERE id = ?',
-				array($_SESSION['sess_user_id']));
+		$user = db_fetch_row_prepared('SELECT policy_trees
+			FROM user_auth
+			WHERE id = ?',
+			array($_SESSION['sess_user_id']));
 
-			if ($user['policy_trees'] == 1) {
-				$default_tree_id = db_fetch_cell_prepared('SELECT graph_tree.id
-					FROM graph_tree
-					LEFT JOIN user_auth_perms ON user_auth_perms.item_id = graph_tree.id
-					AND user_auth_perms.type = 2
-					AND user_auth_perms.user_id = ?
-					WHERE user_auth_perms.item_id IS NULL
-					AND graph_tree.enabled = "on"
-					ORDER BY graph_tree.id
-					LIMIT 1',
-					array($_SESSION['sess_user_id']));
-			} else {
-				$default_tree_id = db_fetch_cell('SELECT graph_tree.id
-					FROM graph_tree
-					INNER JOIN user_auth_perms ON user_auth_perms.item_id = graph_tree.id
-					AND user_auth_perms.type = 2
-					AND user_auth_perms.user_id = ?
-					WHERE graph_tree.enabled = "on"
-					ORDER BY graph_tree.id
-					LIMIT 1',
-					array($_SESSION['sess_user_id']));
-			}
+		if ($user['policy_trees'] == 1) {
+			$default_tree_id = db_fetch_cell_prepared('SELECT graph_tree.id
+				FROM graph_tree
+				LEFT JOIN user_auth_perms ON user_auth_perms.item_id = graph_tree.id
+				AND user_auth_perms.type = 2
+				AND user_auth_perms.user_id = ?
+				WHERE user_auth_perms.item_id IS NULL
+				AND graph_tree.enabled = "on"
+				ORDER BY graph_tree.id
+				LIMIT 1',
+				array($_SESSION['sess_user_id']));
+		} else {
+			$default_tree_id = db_fetch_cell('SELECT graph_tree.id
+				FROM graph_tree
+				INNER JOIN user_auth_perms ON user_auth_perms.item_id = graph_tree.id
+				AND user_auth_perms.type = 2
+				AND user_auth_perms.user_id = ?
+				WHERE graph_tree.enabled = "on"
+				ORDER BY graph_tree.id
+				LIMIT 1',
+				array($_SESSION['sess_user_id']));
 		}
 	} else {
 		$default_tree_id = db_fetch_cell('SELECT id FROM graph_tree ORDER BY sequence LIMIT 1');
@@ -148,13 +148,30 @@ function grow_dhtml_trees() {
 
 	var search_to = false;
 
-	function resizeGraphContent() {
-		docHeight  = parseInt($('body').height());
-		navigation = $('.cactiTreeNavigationArea').offset();
-		navHeight  = docHeight - navigation.top + 15;
-		visWidth   = Math.max.apply(Math, $('.jstree').children(':visible').map(function() { return $(this).width(); }).get());
-		$('.cactiTreeNavigationArea').height(navHeight).width(visWidth);
-		$('.cactiGraphContentArea').css('margin-left', visWidth+10);
+        <?php
+	if (read_user_setting('tree_history') != 'on') {
+		print 'window.onunload = function() { localStorage.removeItem(\'graph_tree_history\'); }';
+	}
+        ?>
+
+	function resizeTreePanel() {
+		if (theme != 'classic') {
+			docHeight  = parseInt($('body').height());
+			navigation = $('.cactiTreeNavigationArea').offset();
+			navWidth   = $('.cactiTreeNavigationArea').outerWidth();
+			navHeight  = docHeight - navigation.top + 15;
+			visWidth   = Math.max.apply(Math, $('.jstree').children(':visible').map(function() {
+				return $(this).width();
+			}).get());
+
+			if (visWidth > navWidth) {
+				$('.cactiTreeNavigationArea').height(navHeight).width(visWidth);
+				$('.cactiGraphContentArea').css('margin-left', visWidth+5);
+			} else {
+				$('.cactiTreeNavigationArea').height(navHeight).width(navWidth);
+				$('.cactiGraphContentArea').css('margin-left', navWidth+5);
+			}
+		}
 	}
 
 	function checkTreeForLogout() {
@@ -176,15 +193,13 @@ function grow_dhtml_trees() {
 						return $.Deferred(function(def) {
 							id = $('a[id^='+name+']').first().attr('id');
 
-							//console.log('lastNode:'+lastNode+', Node:'+name);
 							if (lastNode == name) {
-								//console.log('lastNode:'+lastNode+', Node:'+name+', Id:'+id+', Select Node');
 								$('#jstree').jstree('select_node', id, function() {
 									def.resolve();
 								});
 							} else {
-								//console.log('lastNode:'+lastNode+', Node:'+name+', Id:'+id+', Open Node');
 								$('#jstree').jstree('open_node', id, function() {
+									$('.cactiConsoleNavigationArea').css('overflow-y', 'auto');
 									def.resolve();
 								});
 							}
@@ -207,63 +222,48 @@ function grow_dhtml_trees() {
 			})
 			.on('loaded.jstree', function() {
 				openNodes();
+				resizeTreePanel();
 			})
 			.on('ready.jstree', function() {
-				resizeGraphContent();
+				resizeTreePanel();
 			})
 			.on('changed.jstree', function() {
-				resizeGraphContent();
+				resizeTreePanel();
 			})
 			.on('before_open.jstree', function() {
 				checkTreeForLogout();
 			})
 			.on('open_node.jstree', function() {
-				resizeGraphContent();
+				$(window).trigger('resize');
+				resizeTreePanel();
+				responsiveResizeGraphs();
 			})
 			.on('close_node.jstree', function() {
-				resizeGraphContent();
+				$(window).trigger('resize');
+				resizeTreePanel();
+				responsiveResizeGraphs();
 			})
 			.on('select_node.jstree', function(e, data) {
 				if (data.node.id) {
 					if (data.node.id.search('tree_anchor') >= 0) {
 						href=$('#'+data.node.id).find('a:first').attr('href');
-						//href=$('#'+data.node.id).find('a:first').attr('href')+"&node=0";
 					} else {
-						//href=$('#'+data.node.id).find('a:first').attr('href')+"&node="+data.node.id.replace('tbranch-','');
 						href=$('#'+data.node.id).find('a:first').attr('href');
 					}
 
 					origHref = href;
 
 					if (typeof href !== 'undefined') {
-						href=href.replace('action=tree', 'action=tree_content');
+						href = href.replace('action=tree', 'action=tree_content');
+						href = href + '&hyper=true';
 						$('.cactiGraphContentArea').hide();
-
-						$.get(href)
-							.done(function(data) {
-								$('#main').html(data);
-								applySkin();
-
-								$('.cactiGraphContentArea').show();
-
-								var mytitle = 'Tree Mode - '+$('#nav_title').text();
-								document.getElementsByTagName('title')[0].innerHTML = mytitle;
-								if (typeof window.history.pushState !== 'undefined') {
-									window.history.pushState({ page: origHref+'&hyper=true' }, mytitle, origHref+'&hyper=true');
-								}
-
-								window.scrollTo(0, 0);
-								resizeGraphContent();
-							})
-							.fail(function(data) {
-								getPresentHTTPError(data);
-							});
+						loadPage(href);
 					}
 
 					node = data.node.id;
 				}
 
-				resizeGraphContent();
+				resizeTreePanel();
 			})
 			.jstree({
 				'types' : {
@@ -321,7 +321,7 @@ function grow_dhtml_trees() {
 					'dots' : false
 				},
 				'state' : { 'key' : 'graph_tree_history' },
-				'search' : { 'case_sensitive' : false, 'show_only_matches' : true, 'ajax' : { 'url' : 'graph_view.php?action=ajax_search'} },
+				'search' : { 'case_sensitive' : false, 'show_only_matches' : true, 'ajax' : { 'url' : urlPath+'graph_view.php?action=ajax_search'} },
 				'plugins' : [ 'types', 'state', 'wholerow', 'search' ]
 			});
 		});
@@ -335,7 +335,7 @@ function grow_dhtml_trees() {
 		});
 
 		$(document).resize(function() {
-			resizeGraphContent();
+			resizeTreePanel();
 		});
 
 		<?php print api_plugin_hook_function('top_graph_jquery_function');?>
@@ -491,7 +491,7 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0) {
 			$dhtml_tree[] = "<ul>\n";
 
 			foreach($heirarchy as $h) {
-				$dhtml_tree[] = "<li id='tree_anchor-" . $h['tree_id'] . "' data-jstree='{ \"type\" : \"tree\" }' class='jstree-closed'><a href='" . html_escape('graph_view.php?action=tree&node=tree_anchor-' . $h['tree_id'] . '&site_id=-1&host_id=-1&host_template_id=-1&hgd=') . "'>" . html_escape($h['title']) . "</a></li>\n";
+				$dhtml_tree[] = "<li id='tree_anchor-" . $h['tree_id'] . "' data-jstree='{ \"type\" : \"tree\" }' class='jstree-closed'><a href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tree_anchor-' . $h['tree_id'] . '&site_id=-1&host_id=-1&host_template_id=-1&hgd=') . "'>" . html_escape($h['title']) . "</a></li>\n";
 			}
 
 			$dhtml_tree[] = "</ul>\n";
@@ -502,13 +502,13 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0) {
 }
 
 function create_site_branch($leaf) {
-	global $unique_id;
+	global $config, $unique_id;
 
 	$unique_id++;
 
 	$dhtml_tree   = array();
 
-	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . "-site-" . $leaf['site_id'] . "' data-jstree='{ \"type\" : \"site\" }'><a href=\"" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&host_id=-1&host_template_id=-1&hgd=') . '">' . html_escape($leaf['sitename']) . "</a>\n";
+	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . "-site-" . $leaf['site_id'] . "' data-jstree='{ \"type\" : \"site\" }'><a href=\"" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&host_id=-1&host_template_id=-1&hgd=') . '">' . html_escape($leaf['sitename']) . "</a>\n";
 
 	$devices = get_allowed_site_devices($leaf['site_id'], '', 'ht.name ASC, h1.description ASC');
 	$ht_name = '';
@@ -522,7 +522,7 @@ function create_site_branch($leaf) {
 					$dhtml_tree[] = "</ul></li>\n";
 				}
 
-				$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-ht-' . $d['host_template_id'] . "' data-jstree='{ \"type\" : \"host_template\" }'><a href='" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&host_template_id=' . $d['host_template_id'] . '&host_id=-1&hgd=') . "'>" . html_escape($d['host_template_name']) . "</a><ul>\n";
+				$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-ht-' . $d['host_template_id'] . "' data-jstree='{ \"type\" : \"host_template\" }'><a href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&host_template_id=' . $d['host_template_id'] . '&host_id=-1&hgd=') . "'>" . html_escape($d['host_template_name']) . "</a><ul>\n";
 			}
 
 			$hleaf = $leaf;
@@ -545,11 +545,11 @@ function create_site_branch($leaf) {
 
 	if (cacti_sizeof($graph_templates)) {
 		$dhtml_tree[] = "\t\t\t\t\t\t<ul>\n";
-		$dhtml_tree[] = "\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-gts' . "' data-jstree='{ \"type\" : \"graph_templates\" }'><a href='" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&gti=-1&host_id=-1&host_template_id=-1&hgd=') . "'>" . __('Graph Templates') . "</a>\n";
+		$dhtml_tree[] = "\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-gts' . "' data-jstree='{ \"type\" : \"graph_templates\" }'><a href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&gti=-1&host_id=-1&host_template_id=-1&hgd=') . "'>" . __('Graph Templates') . "</a>\n";
 		$dhtml_tree[] = "\t\t\t\t\t\t\t<ul>\n";
 
 		foreach ($graph_templates as $graph_template) {
-			$dhtml_tree[] = "\t\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-gts-gt-' . $graph_template['id'] . "' data-jstree='{ \"type\" : \"graph_template\" }'><a href='" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&gti=' . $graph_template['id'] . '&host_id=' . $leaf['host_id'] . '&host_template_id=-1&hgd=gt:' . $graph_template['id']) . "'>" . html_escape($graph_template['name']) . "</a></li>\n";
+			$dhtml_tree[] = "\t\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-site-' . $leaf['site_id'] . '-gts-gt-' . $graph_template['id'] . "' data-jstree='{ \"type\" : \"graph_template\" }'><a href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=' . $leaf['site_id'] . '&gti=' . $graph_template['id'] . '&host_id=' . $leaf['host_id'] . '&host_template_id=-1&hgd=gt:' . $graph_template['id']) . "'>" . html_escape($graph_template['name']) . "</a></li>\n";
 		}
 
 		$dhtml_tree[] = "\t\t\t\t\t\t\t</ul>\n";
@@ -563,6 +563,8 @@ function create_site_branch($leaf) {
 }
 
 function create_branch($leaf) {
+	global $config;
+
 	$dhtml_tree = array();
 
 	$children = db_fetch_cell_prepared('SELECT COUNT(*)
@@ -571,17 +573,17 @@ function create_branch($leaf) {
 		AND local_graph_id=0',
 		array($leaf['id']));
 
-	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . "' " . ($children > 0 ? "class='jstree-closed'":"") . "><a href=\"" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=-1&host_id=-1&host_template_id=-1&hgd=') . '">' . html_escape($leaf['title']) . "</a></li>\n";
+	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . "' " . ($children > 0 ? "class='jstree-closed'":"") . "><a href=\"" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&site_id=-1&host_id=-1&host_template_id=-1&hgd=') . '">' . html_escape($leaf['title']) . "</a></li>\n";
 
 	return $dhtml_tree;
 }
 
 function create_host_branch($leaf, $site_id = -1, $ht = -1) {
-	global $unique_id;
+	global $config, $unique_id;
 
 	$unique_id++;
 
-	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id:'') . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id'] . '-uid-' . $unique_id . "' data-jstree='{ \"type\" : \"device\" }'><a href=\"" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht .'&hgd=') . '">' . html_escape($leaf['hostname']) . "</a>\n";
+	$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id:'') . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id'] . '-uid-' . $unique_id . "' data-jstree='{ \"type\" : \"device\" }'><a href=\"" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht .'&hgd=') . '">' . html_escape($leaf['hostname']) . "</a>\n";
 
 	if (read_user_setting('expand_hosts') == 'on') {
 		if ($leaf['host_grouping_type'] == HOST_GROUPING_DATA_QUERY_INDEX) {
@@ -608,7 +610,7 @@ function create_host_branch($leaf, $site_id = -1, $ht = -1) {
 }
 
 function create_graph_template_branch($leaf, $site_id = -1, $ht = -1) {
-	global $unique_id;
+	global $config, $unique_id;
 
 	$dhtml_tree = array();
 
@@ -621,7 +623,7 @@ function create_graph_template_branch($leaf, $site_id = -1, $ht = -1) {
 		foreach ($graph_templates as $graph_template) {
 			$unique_id++;
 
-			$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-gt-' . $graph_template['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"graph_template\" }'><a href='" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=gt:' . $graph_template['id']) . "'>" . html_escape($graph_template['name']) . "</a></li>\n";
+			$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-gt-' . $graph_template['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"graph_template\" }'><a href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=gt:' . $graph_template['id']) . "'>" . html_escape($graph_template['name']) . "</a></li>\n";
 		}
 	}
 
@@ -629,7 +631,7 @@ function create_graph_template_branch($leaf, $site_id = -1, $ht = -1) {
 }
 
 function create_data_query_branch($leaf, $site_id = -1, $ht = -1) {
-	global $unique_id;
+	global $config, $unique_id;
 
 	$dhtml_tree = array();
 
@@ -673,9 +675,9 @@ function create_data_query_branch($leaf, $site_id = -1, $ht = -1) {
 				$unique_id++;
 
 				if ($data_query['name'] != __('Non Query Based')) {
-					$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dq:' . $data_query['id']) . '">' . html_escape($data_query['name']) . "</a>\n";
+					$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dq:' . $data_query['id']) . '">' . html_escape($data_query['name']) . "</a>\n";
 				} else {
-					$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dq:' . $data_query['id']) . '">' . html_escape($data_query['name']) . "</a>\n";
+					$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . "-uid-$unique_id' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dq:' . $data_query['id']) . '">' . html_escape($data_query['name']) . "</a>\n";
 				}
 
 				if ($data_query['id'] > 0) {
@@ -683,7 +685,7 @@ function create_data_query_branch($leaf, $site_id = -1, $ht = -1) {
 					foreach ($sfd as $snmp_index => $sort_field_value) {
 						$unique_id++;
 
-						$dhtml_tree[] = "\t\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . '-' . urlencode($snmp_index) . "-uid-$unique_id' data-jstree='{ \"type\" : \"graph\" }'><a class='treepick' href='" . html_escape('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dqi:' . $data_query['id'] . ':' . $snmp_index) . "'>" . html_escape($sort_field_value) . "</a></li>\n";
+						$dhtml_tree[] = "\t\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . ($site_id > 0 ? '-site-' . $site_id . ($ht > 0 ? '-ht-' . $ht:'') . '-host-' . $leaf['host_id']:'') . '-dq-' . $data_query['id'] . '-' . urlencode($snmp_index) . "-uid-$unique_id' data-jstree='{ \"type\" : \"graph\" }'><a class='treepick' href='" . html_escape($config['url_path'] . 'graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&host_id=' . $leaf['host_id'] . '&site_id=' . $site_id . '&host_template_id=' . $ht . '&hgd=dqi:' . $data_query['id'] . ':' . $snmp_index) . "'>" . html_escape($sort_field_value) . "</a></li>\n";
 					}
 
 					$dhtml_tree[] = "\t\t\t\t\t\t\t</ul>\n";
@@ -1041,7 +1043,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	</tr>
 	<tr class='even noprint'>
 		<td class='noprint'>
-		<form name='form_timespan_selector' method='post' action='graph_view.php'>
+		<form name='form_timespan_selector' method='post' action='<?php print $config['url_path'];?>graph_view.php'>
 			<table class='filterTable'>
 				<tr id='timespan'>
 					<td>
@@ -1154,7 +1156,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	var graph_end   = <?php print get_current_graph_end();?>;
 	var timeOffset  = <?php print date('Z');?>;
 	var pageAction  = 'tree';
-	var graphPage   = 'graph_view.php';
+	var graphPage   = '<?php print $config['url_path'];?>graph_view.php';
 	var hgd         = '<?php print $host_group_data;?>';
 	var date1Open   = false;
 	var date2Open   = false;
@@ -1313,7 +1315,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	$total_rows = cacti_sizeof($graph_list);
 
 	/* generate page list */
-	$nav = html_nav_bar("graph_view.php?action=tree_content&tree_id=$tree_id&leaf_id=$leaf_id&node=" . get_request_var('node') . '&hgd=' . $host_group_data, MAX_DISPLAY_PAGES, get_request_var('page'), get_request_var('graphs'), $total_rows, get_request_var('columns'), __('Graphs'), 'page', 'main');
+	$nav = html_nav_bar($config['url_path'] . 'graph_view.php?action=tree_content&tree_id=' . $tree_id . '&leaf_id=' . $leaf_id . '&node=' . get_request_var('node') . '&hgd=' . $host_group_data, MAX_DISPLAY_PAGES, get_request_var('page'), get_request_var('graphs'), $total_rows, get_request_var('columns'), __('Graphs'), 'page', 'main');
 
 	print $nav;
 
@@ -1398,31 +1400,31 @@ function get_host_graph_list($host_id, $graph_template_id, $data_query_id, $host
 		);
 
 		if (cacti_sizeof($final_templates)) {
+			$sql_where = '';
+			if (get_request_var('rfilter') != '') {
+				$sql_where = " (gtg.title_cache RLIKE '" . get_request_var('rfilter') . "')";
+			}
+
+			if ($host_id > 0) {
+				$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.host_id=' . $host_id;
+			}
+
+			$graph_template_ids = [];
 			foreach ($final_templates as $graph_template) {
-				$sql_where = '';
+				array_push($graph_template_ids, $graph_template['id']);
+			}
+			$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.graph_template_id IN (' . implode(', ', $graph_template_ids) . ')';
+			$graphs = get_allowed_graphs($sql_where);
+			$agg    = get_allowed_aggregate_graphs($sql_where);
+			$graphs = array_merge($graphs, $agg);
 
-				if (get_request_var('rfilter') != '') {
-					$sql_where = " (gtg.title_cache RLIKE '" . get_request_var('rfilter') . "')";
-				}
+			/* let's sort the graphs naturally */
+			usort($graphs, 'naturally_sort_graphs');
 
-				if ($host_id > 0) {
-					$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.host_id=' . $host_id;
-				}
-
-				$sql_where .= ($sql_where != '' ? ' AND ':'') . 'gl.graph_template_id=' . $graph_template['id'];
-
-				$graphs = get_allowed_graphs($sql_where);
-				$agg    = get_allowed_aggregate_graphs($sql_where);
-				$graphs = array_merge($graphs, $agg);
-
-				/* let's sort the graphs naturally */
-				usort($graphs, 'naturally_sort_graphs');
-
-				if (cacti_sizeof($graphs)) {
-					foreach ($graphs as $graph) {
-						$graph['graph_template_name'] = $graph_template['name'];
-						array_push($graph_list, $graph);
-					}
+			if (cacti_sizeof($graphs)) {
+				foreach ($graphs as $graph) {
+					$graph['graph_template_name'] = $graph_template['name'];
+					array_push($graph_list, $graph);
 				}
 			}
 		}
