@@ -738,8 +738,23 @@ function update_order_string($inplace = false) {
 			$_SESSION['sort_data'][$page][get_request_var('sort_column')] = get_request_var('sort_direction');
 			$_SESSION['sort_string'][$page] = 'ORDER BY ' . $del . implode($del . '.'. $del, explode('.', get_request_var('sort_column'))) . $del . ' ' . get_request_var('sort_direction');
 		} elseif (isset_request_var('sort_column')) {
+			if (isset_request_var('reset')) {
+				unset($_SESSION['sort_data'][$page]);
+				unset($_SESSION['sort_string'][$page]);
+			}
+
 			$_SESSION['sort_data'][$page][get_request_var('sort_column')] = get_nfilter_request_var('sort_direction');
 			$_SESSION['sort_string'][$page] = 'ORDER BY ';
+
+			foreach($_SESSION['sort_data'][$page] as $column => $direction) {
+				if (strpos($column, '(') === false && strpos($column, '`') === false) {
+					$del = '`';
+				} else {
+					$del = '';
+					break;
+				}
+			}
+
 			foreach($_SESSION['sort_data'][$page] as $column => $direction) {
 				if ($column == 'hostname' || $column == 'ip' || $column == 'ip_address') {
 					$order .= ($order != '' ? ', ':'') . 'INET_ATON(' . $column . ") " . $direction;
@@ -797,8 +812,6 @@ function get_order_string_page() {
 }
 
 function validate_is_regex($regex) {
-	global $php_errormsg;
-
 	if ($regex == '') {
 		return true;
 	}
@@ -813,7 +826,9 @@ function validate_is_regex($regex) {
 		return true;
 	}
 
-	$php_error = trim(str_replace('preg_match():', '', $php_errormsg));
+	$last_error = error_get_last();
+
+	$php_error = trim(str_replace('preg_match():', '', $last_error['message']));
 
 	ini_set('track_errors', $track_errors);
 
