@@ -570,21 +570,11 @@ function snmpagent_get_pluginslist(){
 	$dh   = opendir($path);
 	if ($dh !== false) {
 		while (($file = readdir($dh)) !== false) {
-			if ((is_dir("$path/$file")) && !in_array($file, $plugins_integrated) &&
-				(file_exists("$path/$file/setup.php")) && (!array_key_exists($file, $pluginslist))) {
-				if (file_exists("$path/$file/INFO")) {
-					$cinfo = plugin_load_info_file("$path/$file/INFO");
-
-					if (!isset($cinfo['author']))   $cinfo['author']   = 'Unknown';
-					if (!isset($cinfo['homepage'])) $cinfo['homepage'] = 'Not Stated';
-					if (isset($cinfo['webpage']))   $cinfo['homepage'] = $cinfo['webpage'];
-					if (!isset($cinfo['longname'])) $cinfo['longname'] = ucfirst($file);
-					$cinfo['directory'] = $file;
-
+			if ((is_dir("$path$file")) && !in_array($file, $plugins_integrated) &&
+				(file_exists("$path$file/setup.php")) && (!array_key_exists($file, $pluginslist))) {
+				if (file_exists("$path$file/INFO")) {
+					$cinfo = plugin_load_info_file("$path$file/INFO");
 					$pluginslist[$file] = $cinfo;
-					if (!isset($pluginslist[$file]['status'])) {
-						$pluginslist[$file]['status'] = 0;
-					}
 				}
 			}
 		}
