@@ -722,10 +722,12 @@ function push_out_host($host_id, $local_data_id = 0, $data_template_id = 0) {
 
 	if (cacti_sizeof($hosts)) {
 		foreach($hosts as $host) {
-			$poller_ids[$host['poller_id']] = $host['poller_id'];
+			if (isset($host['poller_id'])) {
+				$poller_ids[$host['poller_id']] = $host['poller_id'];
+			}
 		}
 
-		if (cacti_sizeof($poller_ids > 1)) {
+		if (cacti_sizeof($poller_ids) > 1) {
 			cacti_log('WARNING: function push_out_host() discovered more than a single host', false, 'POLLER');
 		}
 	}
@@ -810,6 +812,7 @@ function utilities_get_mysql_recommendations() {
 	// MySQL/MariaDB Important Variables
 	// Assume we are successfully, until we aren't!
 	$result = DB_STATUS_SUCCESS;
+
 	$variables = array_rekey(db_fetch_assoc('SHOW GLOBAL VARIABLES'), 'Variable_name', 'Value');
 
 	$memInfo = utilities_get_system_memory();
@@ -832,20 +835,21 @@ function utilities_get_mysql_recommendations() {
 	$recommendations = array(
 		'version' => array(
 			'value' => '5.6',
+			'class' => 'warning',
 			'measure' => 'ge',
 			'comment' => __('MySQL 5.6+ and MariaDB 10.0+ are great releases, and are very good versions to choose. Make sure you run the very latest release though which fixes a long standing low level networking issue that was causing spine many issues with reliability.')
 			)
 	);
 
 	if (isset($variables['innodb_version']) && version_compare($variables['innodb_version'], '5.6', '<')) {
-		if (version_compare($link_ver, '5.2', '>=')) {
+		if (version_compare($link_ver, '5.5', '>=')) {
 			if (!isset($variables['innodb_version'])) {
 				$recommendations += array(
 					'innodb' => array(
 						'value' => 'ON',
 						'class' => 'warning',
-						'measure' => 'equal',
-						'comment' => __('It is recommended that you enable InnoDB in any %s version greater than 5.1.', $database)
+						'measure' => 'equalint',
+						'comment' => __('It is STRONGLY recommended that you enable InnoDB in any %s version greater than 5.5.3.', $database)
 					)
 				);
 
@@ -855,13 +859,13 @@ function utilities_get_mysql_recommendations() {
 
 		$recommendations += array(
 			'collation_server' => array(
-				'value' => 'utf8_general_ci',
+				'value' => 'utf8mb4_unicode_ci',
 				'class' => 'warning',
 				'measure' => 'equal',
 				'comment' => __('When using Cacti with languages other than English, it is important to use the utf8_general_ci collation type as some characters take more than a single byte.  If you are first just now installing Cacti, stop, make the changes and start over again.  If your Cacti has been running and is in production, see the internet for instructions on converting your databases and tables if you plan on supporting other languages.')
 				),
 			'character_set_client' => array(
-				'value' => 'utf8',
+				'value' => 'utf8mb4',
 				'class' => 'warning',
 				'measure' => 'equal',
 				'comment' => __('When using Cacti with languages other than English, it is important to use the utf8 character set as some characters take more than a single byte. If you are first just now installing Cacti, stop, make the changes and start over again. If your Cacti has been running and is in production, see the internet for instructions on converting your databases and tables if you plan on supporting other languages.')
@@ -874,7 +878,7 @@ function utilities_get_mysql_recommendations() {
 					'innodb' => array(
 						'value' => 'ON',
 						'class' => 'warning',
-						'measure' => 'equal',
+						'measure' => 'equalint',
 						'comment' => __('It is recommended that you enable InnoDB in any %s version greater than 5.1.', $database)
 					)
 				);
@@ -934,14 +938,21 @@ function utilities_get_mysql_recommendations() {
 			),
 		'innodb_file_per_table' => array(
 			'value'   => 'ON',
-			'measure' => 'equal',
+			'measure' => 'equalint',
 			'comment' => __('When using InnoDB storage it is important to keep your table spaces separate.  This makes managing the tables simpler for long time users of %s.  If you are running with this currently off, you can migrate to the per file storage by enabling the feature, and then running an alter statement on all InnoDB tables.', $database)
 			),
 		'innodb_file_format' => array(
 			'value'   => 'Barracuda',
 			'measure' => 'equal',
+			'class'   => 'error',
 			'comment' => __('When using innodb_file_per_table, it is important to set the innodb_file_format to Barracuda.  This setting will allow longer indexes important for certain Cacti tables.')
 			),
+		'innodb_large_prefix' => array(
+			'value'   => '1',
+			'measure' => 'equalint',
+			'class'   => 'error',
+			'comment' => __('If your tables have very large indexes, you must operate with the Barracuda innodb_file_format and the innodb_large_prefix equal to 1.  Failure to do this may result in plugins that can not properly create tables.')
+			),
 		'innodb_buffer_pool_size' => array(
 			'value'   => '25',
 			'measure' => 'pmem',
@@ -950,7 +961,7 @@ function utilities_get_mysql_recommendations() {
 			),
 		'innodb_doublewrite' => array(
 			'value'   => 'OFF',
-			'measure' => 'equal',
+			'measure' => 'equalint',
 			'class' => 'warning',
 			'comment' => __('With modern SSD type storage, this operation actually degrades the disk more rapidly and adds a 50%% overhead on all write operations.')
 			),
@@ -963,6 +974,11 @@ function utilities_get_mysql_recommendations() {
 			'value'   => '50',
 			'measure' => 'ge',
 			'comment' => __('Rogue queries should not for the database to go offline to others.  Kill these queries before they kill your system.')
+			),
+		'innodb_flush_method' => array(
+			'value'   => 'O_DIRECT',
+			'measure' => 'eq',
+			'comment' => __('Maximum I/O performance happens when you use the O_DIRECT method to flush pages.')
 			)
 	);
 
@@ -1002,6 +1018,24 @@ function utilities_get_mysql_recommendations() {
 					'measure' => 'pinst',
 					'class' => 'warning',
 					'comment' => __('%s will divide the innodb_buffer_pool into memory regions to improve performance.  The max value is 64.  When your innodb_buffer_pool is less than 1GB, you should use the pool size divided by 128MB.  Continue to use this equation upto the max of 64.', $database)
+					),
+				'innodb_io_capacity' => array(
+					'value' => '5000',
+					'measure' => 'ge',
+					'class' => 'warning',
+					'comment' => __('If you have SSD disks, use this suggestion.  If you have physical hard drives, use 200 * the number of active drives in the array.  If using NVMe or PCIe Flash, much larger numbers as high as 100000 can be used.')
+					),
+				'innodb_io_capacity_max' => array(
+					'value' => '10000',
+					'measure' => 'ge',
+					'class' => 'warning',
+					'comment' => __('If you have SSD disks, use this suggestion.  If you have physical hard drives, use 2000 * the number of active drives in the array.  If using NVMe or PCIe Flash, much larger numbers as high as 200000 can be used.')
+					),
+				'innodb_flush_neighbor_pages' => array(
+					'value' => 'none',
+					'measure' => 'eq',
+					'class' => 'warning',
+					'comment' => __('If you have SSD disks, use this suggestion. Otherwise, do not set this setting.')
 					)
 			);
 
@@ -1034,13 +1068,13 @@ function utilities_get_mysql_recommendations() {
 
 			$compare = '';
 			$value_recommend = isset($r['value']) ? $r['value'] : '<unset>';
-			$value_current = isset($variables[$name]) ? $variables[$name] : '<unset>';
-			$value_display = $value_current;
+			$value_current   = isset($variables[$name]) ? $variables[$name] : '<unset>';
+			$value_display   = $value_current;
 
 			switch($r['measure']) {
 			case 'gem':
 				$compare = '>=';
-				$value_display = ($variables[$name]/1024/1024).'M';
+				$value_display = ($variables[$name]/1024/1024) . 'M';
 				$value = trim($r['value'], 'M') * 1024 * 1024;
 				if ($variables[$name] < $value) {
 					$passed = false;
@@ -1050,9 +1084,20 @@ function utilities_get_mysql_recommendations() {
 				$compare = '>=';
 				$passed = (version_compare($value_current, $value_recommend, '>='));
 				break;
+			case 'equalint':
 			case 'equal':
 				$compare = '=';
-				$passed = (isset($variables[$name]) || $value_current != $value_recommend);
+				if (!isset($variables[$name])) {
+					$passed = false;
+				} else {
+					$e_var = $variables[$name];
+					$e_rec = $value_recommend;
+					if ($r['measure'] == 'equalint') {
+						$e_var = (!strcasecmp('on', $e_var) ? 1 : (!strcasecmp('off', $e_var) ? 0 : $e_var));
+						$e_rec = (!strcasecmp('on', $e_rec) ? 1 : (!strcasecmp('off', $e_rec) ? 0 : $e_rec));
+					}
+					$passed = $e_var == $e_rec;
+				}
 				break;
 			case 'pmem':
 				if (isset($memInfo['MemTotal'])) {
@@ -1069,8 +1114,8 @@ function utilities_get_mysql_recommendations() {
 
 				$compare = '>=';
 				$passed = ($variables[$name] >= ($r['value']*$totalMem/100));
-				$value_display = round($variables[$name]/1024/1024,0) . "M";
-				$value_recommend = round($r['value']*$totalMem/100/1024/1024,0) . "M";
+				$value_display = round($variables[$name]/1024/1024,0) . 'M';
+				$value_recommend = round($r['value']*$totalMem/100/1024/1024,0) . 'M';
 				break;
 			case 'pinst':
 				$compare = '>=';
@@ -1266,8 +1311,8 @@ function utility_php_sort_extensions($a, $b) {
 function utility_php_extensions() {
 	global $config;
 
-	$php = read_config_option('path_php_binary', true);
-	$php_file = $config['base_path'] . '/install/cli_check.php extensions';
+	$php = cacti_escapeshellcmd(read_config_option('path_php_binary', true));
+	$php_file = cacti_escapeshellarg($config['base_path'] . '/install/cli_check.php') . ' extensions';
 	$json = shell_exec($php . ' -q ' . $php_file);
 	$ext = @json_decode($json, true);
 
@@ -1285,7 +1330,6 @@ function utility_php_verify_extensions(&$extensions, $source) {
 			'ctype'     => array('cli' => false, 'web' => false),
 			'date'      => array('cli' => false, 'web' => false),
 			'filter'    => array('cli' => false, 'web' => false),
-			'gettext'   => array('cli' => false, 'web' => false),
 			'gd'        => array('cli' => false, 'web' => false),
 			'gmp'       => array('cli' => false, 'web' => false),
 			'hash'      => array('cli' => false, 'web' => false),
@@ -1324,14 +1368,15 @@ function utility_php_verify_extensions(&$extensions, $source) {
 function utility_php_recommends() {
 	global $config;
 
-	$php = read_config_option('path_php_binary', true);
-	$php_file = $config['base_path'] . '/install/cli_check.php recommends';
+	$php = cacti_escapeshellcmd(read_config_option('path_php_binary', true));
+	$php_file = cacti_escapeshellarg($config['base_path'] . '/install/cli_check.php') . ' recommends';
 	$json = shell_exec($php . ' -q ' . $php_file);
-	$ext = array('web'=>'','cli'=>'');
+	$ext = array('web' => '', 'cli' => '');
 	$ext['cli'] = @json_decode($json, true);
 
 	utility_php_verify_recommends($ext['web'], 'web');
 	utility_php_set_recommends_text($ext);
+
 	return $ext;
 }
 
@@ -1381,16 +1426,18 @@ function utility_php_verify_recommends(&$recommends, $source) {
 }
 
 function utility_php_set_recommends_text(&$recs) {
-	foreach ($recs as $name=>$recommends) {
-		foreach ($recommends as $index=>$recommend) {
-			if ($recommend['name'] == 'version') {
-				$recs[$name][$index]['description'] = __('PHP %s is the mimimum version', $recommend['value']);
-			} elseif ($recommend['name'] == 'memory_limit') {
-				$recs[$name][$index]['description'] = __('A minimum of %s MB memory limit', $recommend['value']);
-			} elseif ($recommend['name'] == 'max_execution_time') {
-				$recs[$name][$index]['description'] = __('A minimum of %s m execution time', $recommend['value']);
-			} elseif ($recommend['name'] == 'date.timezone') {
-				$recs[$name][$index]['description'] = __('A valid timezone that matches MySQL and the system');
+	foreach ($recs as $name => $recommends) {
+		if (sizeof($recommends)) {
+			foreach ($recommends as $index => $recommend) {
+				if ($recommend['name'] == 'version') {
+					$recs[$name][$index]['description'] = __('PHP %s is the mimimum version', $recommend['value']);
+				} elseif ($recommend['name'] == 'memory_limit') {
+					$recs[$name][$index]['description'] = __('A minimum of %s MB memory limit', $recommend['value']);
+				} elseif ($recommend['name'] == 'max_execution_time') {
+					$recs[$name][$index]['description'] = __('A minimum of %s m execution time', $recommend['value']);
+				} elseif ($recommend['name'] == 'date.timezone') {
+					$recs[$name][$index]['description'] = __('A valid timezone that matches MySQL and the system');
+				}
 			}
 		}
 	}
@@ -1399,13 +1446,14 @@ function utility_php_set_recommends_text(&$recs) {
 function utility_php_optionals() {
 	global $config;
 
-	$php = read_config_option('path_php_binary', true);
-	$php_file = $config['base_path'] . '/install/cli_check.php optionals';
+	$php = cacti_escapeshellcmd(read_config_option('path_php_binary', true));
+	$php_file = cacti_escapeshellarg($config['base_path'] . '/install/cli_check.php') . ' optionals';
 	$json = shell_exec($php . ' -q ' . $php_file);
 	$opt = @json_decode($json, true);
 
 	utility_php_verify_optionals($opt, 'web');
 	utility_php_set_installed($opt);
+
 	return $opt;
 }
 
@@ -1413,6 +1461,7 @@ function utility_php_verify_optionals(&$optionals, $source) {
 	if (empty($optionals)) {
 		$optionals = array(
 			'snmp'          => array('web' => false, 'cli' => false),
+			'gettext'       => array('web' => false, 'cli' => false),
 			'TrueType Box'  => array('web' => false, 'cli' => false),
 			'TrueType Text' => array('web' => false, 'cli' => false),
 		);
