@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -349,7 +349,7 @@ set_config_option('poller_lastrun_' . $poller_id, (int)$poller_start);
  * plus the poller needs lot's of memory
  */
 ini_set('max_execution_time', MAX_POLLER_RUNTIME + 1);
-ini_set('memory_limit', '512M');
+ini_set('memory_limit', '-1');
 
 $poller_runs_completed = 0;
 $poller_items_total    = 0;
@@ -544,9 +544,9 @@ while ($poller_runs_completed < $poller_runs) {
 
 		// determine command name
 		if ($poller_type == '2') {
-			$command_string = read_config_option('path_spine');
+			$command_string = cacti_escapeshellcmd(read_config_option('path_spine'));
 			if (read_config_option('path_spine_config') != '' && file_exists(read_config_option('path_spine_config'))) {
-				$extra_args     = ' -C ' . read_config_option('path_spine_config');
+				$extra_args     = ' -C ' . cacti_escapeshellarg(read_config_option('path_spine_config'));
 			} else {
 				$extra_args     = '';
 			}
@@ -555,13 +555,13 @@ while ($poller_runs_completed < $poller_runs) {
 			$total_procs    = $concurrent_processes * $max_threads;
 			chdir(dirname(read_config_option('path_spine')));
 		} elseif ($config['cacti_server_os'] == 'unix') {
-			$command_string = read_config_option('path_php_binary');
-			$extra_args     = '-q "' . $config['base_path'] . '/cmd.php"';
+			$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+			$extra_args     = '-q ' . cacti_escapeshellarg($config['base_path'] . '/cmd.php');
 			$method         = 'cmd.php';
 			$total_procs    = $concurrent_processes;
 		} else {
-			$command_string = read_config_option('path_php_binary');
-			$extra_args     = '-q "' . strtolower($config['base_path'] . '/cmd.php"');
+			$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+			$extra_args     = '-q ' . cacti_escapeshellarg(strtolower($config['base_path'] . '/cmd.php'));
 			$method         = 'cmd.php';
 			$total_procs    = $concurrent_processes;
 		}
@@ -706,14 +706,14 @@ while ($poller_runs_completed < $poller_runs) {
 			array($poller_id), '', true, $poller_db_cnn_id);
 
 		if ($commands > 0) {
-			$command_string = read_config_option('path_php_binary');
-			$extra_args = '-q "' . $config['base_path'] . "/poller_commands.php\" --poller=$poller_id";
+			$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+			$extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/poller_commands.php') . ' --poller=' . $poller_id;
 			exec_background($command_string, $extra_args);
 		} else {
 			/* no re-index or Rechache present on this run
 			 * in case, we have more PCOMMANDS than recaching, this has to be moved to poller_commands.php
 			 * but then we'll have to call it each time to make sure, stats are updated */
-			set_config_option('stats_recache_' . $poller_id, 'RecacheTime:0.0 DevicesRecached:0');
+			set_config_option('stats_recache_' . $poller_id, 'Poller:' . $poller_id . ' RecacheTime:0.0 DevicesRecached:0');
 		}
 
 		if ($method == 'spine') {
@@ -794,11 +794,40 @@ if ($poller_id == 1) {
 	automation_poller_bottom();
 	poller_maintenance();
 	api_plugin_hook('poller_bottom');
+	bad_index_check($mibs);
 } else {
 	automation_poller_bottom();
 	poller_maintenance();
 }
 
+function bad_index_check($mibs) {
+	if ($mibs == true) {
+		$bad_index_devices = db_fetch_cell('SELECT GROUP_CONCAT(DISTINCT dl.host_id)
+			FROM data_local dl
+			LEFT JOIN data_template_data dtd
+			ON dtd.local_data_id = dl.id
+			WHERE dl.snmp_query_id > 0
+			AND dl.snmp_index = ""
+			AND dtd.active != ""');
+
+		if ($bad_index_devices != '') {
+			$bad_indexes = db_fetch_cell('SELECT COUNT(*)
+				FROM data_local dl
+				LEFT JOIN data_template_data dtd
+				ON dtd.local_data_id = dl.id
+				WHERE dl.snmp_query_id > 0
+				AND dl.snmp_index = ""
+				AND dtd.active != ""');
+
+
+			$devices = explode(',', $bad_index_devices);
+			$device_str = 'Device[' . implode('], Device[', $devices) . ']';
+
+			cacti_log('WARNING: You have ' . cacti_sizeof($devices) . ' Devices with bad SNMP Indexes.  Devices: ' . $device_str . ' totalling ' . $bad_indexes . ' Data Sources.  Please Either Re-Index, Delete or Disable these Data Sources.', false, 'POLLER');
+		}
+	}
+}
+
 function poller_replicate_check() {
     global $config;
     include_once($config['base_path'] . '/lib/poller.php');
@@ -818,8 +847,8 @@ function poller_replicate_check() {
 		OR (UNIX_TIMESTAMP()-UNIX_TIMESTAMP(last_sync) >= IFNULL(sync_interval, $sync_interval)))");
 
 	foreach($pollers as $poller) {
-		$command_string = read_config_option('path_php_binary');
-		$extra_args = '-q ' . $config['base_path'] . '/cli/poller_replicate.php --poller=' . $poller['id'];
+		$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+		$extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/cli/poller_replicate.php') . ' --poller=' . $poller['id'];
 		exec_background($command_string, $extra_args);
 	}
 }
@@ -925,8 +954,8 @@ function spikekill_poller_bottom () {
     global $config;
     include_once($config['base_path'] . '/lib/poller.php');
 
-    $command_string = read_config_option('path_php_binary');
-    $extra_args = '-q ' . $config['base_path'] . '/poller_spikekill.php';
+    $command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+    $extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/poller_spikekill.php');
     exec_background($command_string, $extra_args);
 }
 
