@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,6 +25,10 @@
 require('./include/auth.php');
 require_once($config['base_path'] . '/lib/poller.php');
 
+/* performing a full sync can take a lot of memory and time */
+ini_set('memory_limit', '-1');
+ini_set('max_execution_time', '900');
+
 $poller_actions = array(
 	1 => __('Delete'),
 	2 => __('Disable'),
@@ -532,7 +536,7 @@ function poller_edit() {
 			unset($fields_poller_edit['dbsslca']);
 		}
 
-		if ($poller['timezone'] == '' || $poller['id'] == 1) {
+		if ($poller['timezone'] == '') {
 			$poller['timezone'] = ini_get('date.timezone');
 		}
 	}
@@ -619,8 +623,6 @@ function poller_edit() {
 			pt = <?php print $pt;?>;
 
 			$(function() {
-				$('#row_timezone').hide();
-
 				if (pt == 1) {
 					$('#row_threads').hide();
 				}
