@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -313,6 +313,9 @@ function vdef_item_remove_confirm() {
 	get_filter_request_var('vdef_id');
 	/* ==================================================== */
 
+	/* sort the vdef functions */
+	asort($vdef_functions);
+
 	form_start('vdef.php');
 
 	html_start_box('', '100%', '', '3', 'center', '');
@@ -375,6 +378,9 @@ function vdef_item_edit() {
 	get_filter_request_var('type_select');
 	/* ==================================================== */
 
+	/* sort the vdef functions */
+	asort($vdef_functions);
+
 	if (!isempty_request_var('id')) {
 		$vdef = db_fetch_row_prepared('SELECT *
 			FROM vdef_items
